@@ -78,6 +78,7 @@ class TelemetrySession:  # pylint: disable=too-many-instance-attributes
         self.enable_broker_on_windows = None
         self.msal_telemetry = None
         self.login_experience_v2 = None
+        self.use_msal_managed_identity = None
 
     def add_event(self, name, properties):
         for key in self.instrumentation_key:
@@ -234,6 +235,7 @@ class TelemetrySession:  # pylint: disable=too-many-instance-attributes
         set_custom_properties(result, 'EnableBrokerOnWindows', str(self.enable_broker_on_windows))
         set_custom_properties(result, 'MsalTelemetry', self.msal_telemetry)
         set_custom_properties(result, 'LoginExperienceV2', str(self.login_experience_v2))
+        set_custom_properties(result, 'UseMsalManagedIdentity', str(self.use_msal_managed_identity))
 
         return result
 
@@ -470,6 +472,7 @@ def set_region_identified(region_input, region_identified):
     _session.region_identified = region_identified
 
 
+# region authentication-related
 @decorators.suppress_all_exceptions()
 def set_broker_info(enable_broker_on_windows):
     # Log the value of `enable_broker_on_windows`
@@ -487,6 +490,12 @@ def set_login_experience_v2(login_experience_v2):
     _session.login_experience_v2 = login_experience_v2
 
 
+@decorators.suppress_all_exceptions()
+def set_use_msal_managed_identity(use_msal_managed_identity):
+    _session.use_msal_managed_identity = use_msal_managed_identity
+# endregion
+
+
 @decorators.suppress_all_exceptions()
 def set_user_agent(user_agent):
     if user_agent:
