@@ -369,7 +369,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
         ctx = None
 
         # test set
-        with self.assertRaisesRegex(InvalidArgumentValueError, "Empty key in --set"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"Empty key in --set"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -379,7 +379,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
                 }
             )
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "Couldn't find '\[1\]' in ''. Available options: \['d', 'd2', 'i', 'l', 'l2', 's'\]"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"Couldn't find '\[1\]' in ''. Available options: \['d', 'd2', 'i', 'l', 'l2', 's'\]"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -389,7 +389,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
                 }
             )
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "Couldn't find 'props' in ''. Available options: \['d', 'd2', 'i', 'l', 'l2', 's'\]"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"Couldn't find 'props' in ''. Available options: \['d', 'd2', 'i', 'l', 'l2', 's'\]"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -399,7 +399,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
                 }
             )
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "Couldn't find 'o' in 'l\[0\]'. Available options: \['p', 's'\]"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"Couldn't find 'o' in 'l\[0\]'. Available options: \['p', 's'\]"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -409,7 +409,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
                 }
             )
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "non-unique key 'p' found"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"non-unique key 'p' found"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -420,7 +420,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
                 }
             )
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "item with value 'x' doesn't exist for key 'p' on l"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"item with value 'x' doesn't exist for key 'p' on l"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -431,7 +431,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
                 }
             )
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "index 10 doesn't exist"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"index 10 doesn't exist"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -441,7 +441,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
                 }
             )
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "Couldn't find 't' in 'l\[1\]'. Available options: \['p', 's'\]"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"Couldn't find 't' in 'l\[1\]'. Available options: \['p', 's'\]"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -451,7 +451,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
                 }
             )
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "`--set property1.property2=<value>`"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"`--set property1.property2=<value>`"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -461,7 +461,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
                 }
             )
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "Expect <class 'str'>, got 3 \(<class 'int'>\)"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"Expect <class 'str'>, got 3 \(<class 'int'>\)"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -471,7 +471,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
                 }
             )
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "index 8 doesn't exist on l"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"index 8 doesn't exist on l"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -481,7 +481,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
                 }
             )
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "Couldn't find '\[10\]' in 'd'. Available options: \['a', 'b', 'c'\]"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"Couldn't find '\[10\]' in 'd'. Available options: \['a', 'b', 'c'\]"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -492,7 +492,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
             )
 
         # test add
-        with self.assertRaisesRegex(InvalidArgumentValueError, "Expect <class 'int'>, got a \(<class 'str'>\)"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"Expect <class 'int'>, got a \(<class 'str'>\)"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -504,7 +504,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
 
         # test remove
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "index 9 doesn't exist"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"index 9 doesn't exist"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -514,7 +514,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
                 }
             )
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "`--remove property.list <indexToRemove>` OR `--remove propertyToRemove`"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"`--remove property.list <indexToRemove>` OR `--remove propertyToRemove`"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -524,7 +524,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
                 }
             )
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "index 2 doesn't exist on l"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"index 2 doesn't exist on l"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
@@ -535,7 +535,7 @@ class TestAAZGenericUpdateOperation(unittest.TestCase):
                 }
             )
 
-        with self.assertRaisesRegex(InvalidArgumentValueError, "index 1 doesn't exist on s"):
+        with self.assertRaisesRegex(InvalidArgumentValueError, r"index 1 doesn't exist on s"):
             AAZGenericInstanceUpdateOperation(ctx)._update_instance_by_generic(
                 instance,
                 {
