@@ -39,23 +39,65 @@ def _build_test_jwt(claims):
     return '.'.join(base64.urlsafe_b64encode(p.encode('utf-8')).decode('utf-8').replace('=', '') for p in parts)
 
 
-class CredentialMock:
+def _now_timestamp_mock():
+    # 2021-09-06 08:55:23
+    return 1630918523
+
+
+class MsalCredentialStub:
 
     def __init__(self, *args, **kwargs):
-        # If get_token_scopes is checked, make sure to create a new instance of CredentialMock
+        # If acquire_token_scopes is checked, make sure to create a new instance of MsalCredentialStub
         # to avoid interference from other tests.
-        self.get_token_scopes = None
+        self.acquire_token_scopes = None
         super().__init__()
 
-    def get_token(self, *scopes, **kwargs):
-        self.get_token_scopes = scopes
-        return AccessToken(MOCK_ACCESS_TOKEN, MOCK_EXPIRES_ON_INT)
+    def acquire_token(self, scopes, **kwargs):
+        self.acquire_token_scopes = scopes
+        return {
+            'access_token': MOCK_ACCESS_TOKEN,
+            'token_type': 'Bearer',
+            'expires_in': 1800,
+            'token_source': 'cache'
+        }
 
 
 # Used as the return_value of azure.cli.core.auth.identity.Identity.get_user_credential
-# If we directly patch azure.cli.core.auth.msal_authentication.UserCredential with CredentialMock,
+# If we directly patch azure.cli.core.auth.msal_authentication.UserCredential with MsalCredentialStub,
 # get_user_credential will prepare MSAL token cache and HTTP cache which is time-consuming and unnecessary.
-credential_mock = CredentialMock()
+credential_mock = MsalCredentialStub()
+
+
+class CloudShellCredentialStub:
+    def __init__(self):
+        self.acquire_token_scopes = None
+        super().__init__()
+
+    def acquire_token(self, scopes, **kwargs):
+        self.acquire_token_scopes = scopes
+        return {
+            'access_token': TestProfile.test_cloud_shell_access_token,
+            'token_type': 'Bearer',
+            'expires_in': 1800,
+            'token_source': 'cache'
+        }
+
+
+class ManagedIdentityCredentialStub:
+    def __init__(self, client_id=None, resource_id=None, object_id=None):
+        self.client_id = client_id
+        self.resource_id = resource_id
+        self.object_id = object_id
+        self.get_token_scopes = None
+
+    def acquire_token(self, scopes, **kwargs):
+        self.get_token_scopes = scopes
+        return {
+            'access_token': TestProfile.test_mi_access_token,
+            'token_type': 'Bearer',
+            'expires_in': 1800,
+            'token_source': 'cache'
+        }
 
 
 class MSRestAzureAuthStub:
@@ -91,15 +133,6 @@ class MSRestAzureAuthStub:
         return AccessToken(self.token['access_token'], int(self.token['expires_on']))
 
 
-class CloudShellCredentialStub:
-    def __init__(self):
-        self.get_token_scopes = None
-
-    def get_token(self, *scopes, **kwargs):
-        self.get_token_scopes = scopes
-        return AccessToken(TestProfile.test_cloud_shell_access_token, MOCK_EXPIRES_ON_INT)
-
-
 class TestProfile(unittest.TestCase):
 
     @classmethod
@@ -255,6 +288,11 @@ class TestProfile(unittest.TestCase):
 
         # A random GUID generated by uuid.uuid4()
         cls.test_mi_tenant = 'b6f04d88-9bff-45da-a9b4-a0b6d3cb1b2a'
+        cls.test_mi_client_id = 'e7bb3d6e-45a3-46c5-aa6a-51783b424587'
+        cls.test_mi_object_id = 'b4cf2750-5e3d-4085-8cb1-1ac4230ae3b6'
+        cls.test_mi_resource_id = (
+            "/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/testrg/providers/"
+            "Microsoft.ManagedIdentity/userAssignedIdentities/testmi")
         cls.test_mi_access_token = _build_test_jwt({'tid': cls.test_mi_tenant})
         cls.test_mi_subscription_id = '796071f3-b997-48d8-87f8-dbc5869bd9c5'
         cls.test_mi_subscription_resource_id = '/subscriptions/{}'.format(cls.test_mi_subscription_id)
@@ -485,7 +523,7 @@ class TestProfile(unittest.TestCase):
 
         # Verify correct scopes are passed to get_token
         credential_instance = create_subscription_client_mock.call_args.args[1]
-        assert credential_instance.get_token_scopes == ('https://management.core.windows.net//.default',)
+        assert credential_instance.acquire_token_scopes == ['https://management.core.windows.net//.default']
 
         self.assertEqual(len(subscriptions), 1)
         s = subscriptions[0]
@@ -498,6 +536,7 @@ class TestProfile(unittest.TestCase):
 
     @mock.patch('requests.get', autospec=True)
     @mock.patch('azure.cli.core._profile.SubscriptionFinder._create_subscription_client', autospec=True)
+    @mock.patch.dict('os.environ', {'AZURE_CORE_USE_MSAL_MANAGED_IDENTITY': 'false'})
     def test_login_with_mi_system_assigned(self, create_subscription_client_mock, mock_get):
         mock_subscription_client = mock.MagicMock()
         mock_subscription_client.subscriptions.list.return_value = [deepcopy(self.subscription1_raw)]
@@ -531,6 +570,7 @@ class TestProfile(unittest.TestCase):
 
     @mock.patch('requests.get', autospec=True)
     @mock.patch('azure.cli.core._profile.SubscriptionFinder._create_subscription_client', autospec=True)
+    @mock.patch.dict('os.environ', {'AZURE_CORE_USE_MSAL_MANAGED_IDENTITY': 'false'})
     def test_login_with_mi_no_subscriptions(self, create_subscription_client_mock, mock_get):
         mock_subscription_client = mock.MagicMock()
         mock_subscription_client.subscriptions.list.return_value = []
@@ -566,6 +606,7 @@ class TestProfile(unittest.TestCase):
 
     @mock.patch('requests.get', autospec=True)
     @mock.patch('azure.cli.core._profile.SubscriptionFinder._create_subscription_client', autospec=True)
+    @mock.patch.dict('os.environ', {'AZURE_CORE_USE_MSAL_MANAGED_IDENTITY': 'false'})
     def test_login_with_mi_user_assigned_client_id(self, create_subscription_client_mock, mock_get):
         mock_subscription_client = mock.MagicMock()
         mock_subscription_client.subscriptions.list.return_value = [deepcopy(self.subscription1_raw)]
@@ -598,21 +639,9 @@ class TestProfile(unittest.TestCase):
         self.assertEqual(s['user']['type'], 'servicePrincipal')
         self.assertEqual(s['user']['assignedIdentityInfo'], 'MSIClient-{}'.format(test_client_id))
 
-        # Old way of using identity_id
-        subscriptions = profile.login_with_managed_identity(identity_id=test_client_id)
-
-        self.assertEqual(len(subscriptions), 1)
-        s = subscriptions[0]
-        self.assertEqual(s['name'], self.display_name1)
-        self.assertEqual(s['id'], self.id1.split('/')[-1])
-        self.assertEqual(s['tenantId'], self.test_mi_tenant)
-
-        self.assertEqual(s['user']['name'], 'userAssignedIdentity')
-        self.assertEqual(s['user']['type'], 'servicePrincipal')
-        self.assertEqual(s['user']['assignedIdentityInfo'], 'MSIClient-{}'.format(test_client_id))
-
     @mock.patch('azure.cli.core.auth.adal_authentication.MSIAuthenticationWrapper', autospec=True)
     @mock.patch('azure.cli.core._profile.SubscriptionFinder._create_subscription_client', autospec=True)
+    @mock.patch.dict('os.environ', {'AZURE_CORE_USE_MSAL_MANAGED_IDENTITY': 'false'})
     def test_login_with_mi_user_assigned_object_id(self, create_subscription_client_mock,
                                                                            mock_msi_auth):
         mock_subscription_client = mock.MagicMock()
@@ -651,16 +680,9 @@ class TestProfile(unittest.TestCase):
         self.assertEqual(s['user']['type'], 'servicePrincipal')
         self.assertEqual(s['user']['assignedIdentityInfo'], 'MSIObject-{}'.format(test_object_id))
 
-        # Old way of using identity_id
-        subscriptions = profile.login_with_managed_identity(identity_id=test_object_id)
-
-        s = subscriptions[0]
-        self.assertEqual(s['user']['name'], 'userAssignedIdentity')
-        self.assertEqual(s['user']['type'], 'servicePrincipal')
-        self.assertEqual(s['user']['assignedIdentityInfo'], 'MSIObject-{}'.format(test_object_id))
-
     @mock.patch('requests.get', autospec=True)
     @mock.patch('azure.cli.core._profile.SubscriptionFinder._create_subscription_client', autospec=True)
+    @mock.patch.dict('os.environ', {'AZURE_CORE_USE_MSAL_MANAGED_IDENTITY': 'false'})
     def test_login_with_mi_user_assigned_resource_id(self, create_subscription_client_mock,
                                                                         mock_get):
 
@@ -692,13 +714,135 @@ class TestProfile(unittest.TestCase):
         self.assertEqual(s['user']['type'], 'servicePrincipal')
         self.assertEqual(subscriptions[0]['user']['assignedIdentityInfo'], 'MSIResource-{}'.format(test_res_id))
 
-        # Old way of using identity_id
-        subscriptions = profile.login_with_managed_identity(identity_id=test_res_id)
+    @mock.patch('azure.cli.core._profile.SubscriptionFinder._create_subscription_client', autospec=True)
+    @mock.patch('azure.cli.core.auth.msal_credentials.ManagedIdentityCredential', ManagedIdentityCredentialStub)
+    def test_login_with_mi_system_assigned_msal(self, create_subscription_client_mock):
+        mock_subscription_client = mock.MagicMock()
+        mock_subscription_client.subscriptions.list.return_value = [deepcopy(self.subscription1_raw)]
+        create_subscription_client_mock.return_value = mock_subscription_client
+
+        cli = DummyCli()
+        storage_mock = {'subscriptions': None}
+        profile = Profile(cli_ctx=cli, storage=storage_mock)
+        subscriptions = profile.login_with_managed_identity()
+
+        credential_instance = create_subscription_client_mock.call_args.args[1]
+        assert credential_instance.client_id is None
+        assert credential_instance.object_id is None
+        assert credential_instance.resource_id is None
+        assert credential_instance.get_token_scopes == ['https://management.core.windows.net//.default']
+
+        self.assertEqual(len(subscriptions), 1)
+        s = subscriptions[0]
+        self.assertEqual(s['user']['name'], 'systemAssignedIdentity')
+        self.assertEqual(s['user']['type'], 'servicePrincipal')
+        self.assertEqual(s['user']['assignedIdentityInfo'], 'MSI')
+        self.assertEqual(s['name'], self.display_name1)
+        self.assertEqual(s['id'], self.id1.split('/')[-1])
+        self.assertEqual(s['tenantId'], self.test_mi_tenant)
+
+    @mock.patch('azure.cli.core._profile.SubscriptionFinder._create_subscription_client', autospec=True)
+    @mock.patch('azure.cli.core.auth.msal_credentials.ManagedIdentityCredential', ManagedIdentityCredentialStub)
+    def test_login_with_mi_system_assigned_no_subscriptions_msal(self, create_subscription_client_mock):
+        mock_subscription_client = mock.MagicMock()
+        mock_subscription_client.subscriptions.list.return_value = []
+        create_subscription_client_mock.return_value = mock_subscription_client
+
+        cli = DummyCli()
+        storage_mock = {'subscriptions': None}
+        profile = Profile(cli_ctx=cli, storage=storage_mock)
+        subscriptions = profile.login_with_managed_identity(allow_no_subscriptions=True)
+
+        credential_instance = create_subscription_client_mock.call_args.args[1]
+        assert credential_instance.client_id is None
+        assert credential_instance.object_id is None
+        assert credential_instance.resource_id is None
+        assert credential_instance.get_token_scopes == ['https://management.core.windows.net//.default']
+
+        self.assertEqual(len(subscriptions), 1)
+        s = subscriptions[0]
+
+        self.assertEqual(s['name'], 'N/A(tenant level account)')
+        self.assertEqual(s['id'], self.test_mi_tenant)
+        self.assertEqual(s['tenantId'], self.test_mi_tenant)
+
+        self.assertEqual(s['user']['name'], 'systemAssignedIdentity')
+        self.assertEqual(s['user']['type'], 'servicePrincipal')
+        self.assertEqual(s['user']['assignedIdentityInfo'], 'MSI')
+
+    @mock.patch('azure.cli.core._profile.SubscriptionFinder._create_subscription_client', autospec=True)
+    @mock.patch('azure.cli.core.auth.msal_credentials.ManagedIdentityCredential', ManagedIdentityCredentialStub)
+    def test_login_with_mi_user_assigned_client_id_msal(self, create_subscription_client_mock):
+        mock_subscription_client = mock.MagicMock()
+        mock_subscription_client.subscriptions.list.return_value = [deepcopy(self.subscription1_raw)]
+        create_subscription_client_mock.return_value = mock_subscription_client
+
+        cli = DummyCli()
+        storage_mock = {'subscriptions': None}
+        profile = Profile(cli_ctx=cli, storage=storage_mock)
+        subscriptions = profile.login_with_managed_identity(client_id=self.test_mi_client_id)
+
+        credential_instance = create_subscription_client_mock.call_args.args[1]
+        assert credential_instance.client_id == self.test_mi_client_id
+        assert credential_instance.object_id is None
+        assert credential_instance.resource_id is None
+        assert credential_instance.get_token_scopes == ['https://management.core.windows.net//.default']
+
+        self.assertEqual(len(subscriptions), 1)
+        s = subscriptions[0]
+        self.assertEqual(s['name'], self.display_name1)
+        self.assertEqual(s['id'], self.id1.split('/')[-1])
+        self.assertEqual(s['tenantId'], self.test_mi_tenant)
+
+        self.assertEqual(s['user']['name'], 'userAssignedIdentity')
+        self.assertEqual(s['user']['type'], 'servicePrincipal')
+        self.assertEqual(s['user']['assignedIdentityInfo'], 'MSIClient-{}'.format(self.test_mi_client_id))
+
+    @mock.patch('azure.cli.core._profile.SubscriptionFinder._create_subscription_client', autospec=True)
+    @mock.patch('azure.cli.core.auth.msal_credentials.ManagedIdentityCredential', ManagedIdentityCredentialStub)
+    def test_login_with_mi_user_assigned_object_id_msal(self, create_subscription_client_mock):
+        mock_subscription_client = mock.MagicMock()
+        mock_subscription_client.subscriptions.list.return_value = [deepcopy(self.subscription1_raw)]
+        create_subscription_client_mock.return_value = mock_subscription_client
+
+        cli = DummyCli()
+        storage_mock = {'subscriptions': None}
+        profile = Profile(cli_ctx=cli, storage=storage_mock)
+        subscriptions = profile.login_with_managed_identity(object_id=self.test_mi_object_id)
+
+        credential_instance = create_subscription_client_mock.call_args.args[1]
+        assert credential_instance.client_id is None
+        assert credential_instance.object_id == self.test_mi_object_id
+        assert credential_instance.resource_id is None
+        assert credential_instance.get_token_scopes == ['https://management.core.windows.net//.default']
 
         s = subscriptions[0]
         self.assertEqual(s['user']['name'], 'userAssignedIdentity')
         self.assertEqual(s['user']['type'], 'servicePrincipal')
-        self.assertEqual(subscriptions[0]['user']['assignedIdentityInfo'], 'MSIResource-{}'.format(test_res_id))
+        self.assertEqual(s['user']['assignedIdentityInfo'], 'MSIObject-{}'.format(self.test_mi_object_id))
+
+    @mock.patch('azure.cli.core._profile.SubscriptionFinder._create_subscription_client', autospec=True)
+    @mock.patch('azure.cli.core.auth.msal_credentials.ManagedIdentityCredential', ManagedIdentityCredentialStub)
+    def test_login_with_mi_user_assigned_resource_id_msal(self, create_subscription_client_mock):
+        mock_subscription_client = mock.MagicMock()
+        mock_subscription_client.subscriptions.list.return_value = [deepcopy(self.subscription1_raw)]
+        create_subscription_client_mock.return_value = mock_subscription_client
+
+        cli = DummyCli()
+        storage_mock = {'subscriptions': None}
+        profile = Profile(cli_ctx=cli, storage=storage_mock)
+        subscriptions = profile.login_with_managed_identity(resource_id=self.test_mi_resource_id)
+
+        credential_instance = create_subscription_client_mock.call_args.args[1]
+        assert credential_instance.client_id is None
+        assert credential_instance.object_id is None
+        assert credential_instance.resource_id == self.test_mi_resource_id
+        assert credential_instance.get_token_scopes == ['https://management.core.windows.net//.default']
+
+        s = subscriptions[0]
+        self.assertEqual(s['user']['name'], 'userAssignedIdentity')
+        self.assertEqual(s['user']['type'], 'servicePrincipal')
+        self.assertEqual(subscriptions[0]['user']['assignedIdentityInfo'], 'MSIResource-{}'.format(self.test_mi_resource_id))
 
     @mock.patch('azure.cli.core._profile.SubscriptionFinder._create_subscription_client', autospec=True)
     @mock.patch('azure.cli.core.auth.identity.Identity.get_user_credential', autospec=True)
@@ -791,37 +935,6 @@ class TestProfile(unittest.TestCase):
         # verify serialization works
         self.assertIsNotNone(json.dumps(consolidated[0]))
 
-    def test_normalize_v2016_06_01(self):
-        cli = DummyCli()
-        storage_mock = {'subscriptions': None}
-        profile = Profile(cli_ctx=cli, storage=storage_mock)
-        from azure.mgmt.resource.subscriptions.v2016_06_01.models import Subscription \
-            as Subscription_v2016_06_01
-        subscription = Subscription_v2016_06_01()
-        subscription.id = self.id1
-        subscription.display_name = self.display_name1
-        subscription.state = self.state1
-        subscription.tenant_id = self.tenant_id
-
-        consolidated = profile._normalize_properties(self.user1, [subscription], False)
-
-        # The subscription shouldn't have managed_by_tenants and home_tenant_id
-        expected = {
-            'id': '1',
-            'name': self.display_name1,
-            'state': 'Enabled',
-            'user': {
-                'name': 'foo@foo.com',
-                'type': 'user'
-            },
-            'isDefault': False,
-            'tenantId': self.tenant_id,
-            'environmentName': 'AzureCloud'
-        }
-        self.assertEqual(expected, consolidated[0])
-        # verify serialization works
-        self.assertIsNotNone(json.dumps(consolidated[0]))
-
     def test_update_add_two_different_subscriptions(self):
         cli = DummyCli()
         storage_mock = {'subscriptions': []}
@@ -1045,6 +1158,7 @@ class TestProfile(unittest.TestCase):
                                                                      aux_tenants=[test_tenant_id2])
 
     @mock.patch('azure.cli.core.auth.adal_authentication.MSIAuthenticationWrapper', MSRestAzureAuthStub)
+    @mock.patch.dict('os.environ', {'AZURE_CORE_USE_MSAL_MANAGED_IDENTITY': 'false'})
     def test_get_login_credentials_mi_system_assigned(self):
         profile = Profile(cli_ctx=DummyCli(), storage={'subscriptions': None})
         consolidated = profile._normalize_properties('systemAssignedIdentity',
@@ -1064,6 +1178,7 @@ class TestProfile(unittest.TestCase):
         self.assertTrue(cred.token_read_count)
 
     @mock.patch('azure.cli.core.auth.adal_authentication.MSIAuthenticationWrapper', MSRestAzureAuthStub)
+    @mock.patch.dict('os.environ', {'AZURE_CORE_USE_MSAL_MANAGED_IDENTITY': 'false'})
     def test_get_login_credentials_mi_user_assigned_with_client_id(self):
         profile = Profile(cli_ctx=DummyCli(), storage={'subscriptions': None})
         test_client_id = '12345678-38d6-4fb2-bad9-b7b93a3e8888'
@@ -1085,6 +1200,7 @@ class TestProfile(unittest.TestCase):
         self.assertTrue(cred.client_id, test_client_id)
 
     @mock.patch('azure.cli.core.auth.adal_authentication.MSIAuthenticationWrapper', MSRestAzureAuthStub)
+    @mock.patch.dict('os.environ', {'AZURE_CORE_USE_MSAL_MANAGED_IDENTITY': 'false'})
     def test_get_login_credentials_mi_user_assigned_with_object_id(self):
         profile = Profile(cli_ctx=DummyCli(), storage={'subscriptions': None})
         test_object_id = '12345678-38d6-4fb2-bad9-b7b93a3e9999'
@@ -1106,6 +1222,7 @@ class TestProfile(unittest.TestCase):
         self.assertTrue(cred.object_id, test_object_id)
 
     @mock.patch('azure.cli.core.auth.adal_authentication.MSIAuthenticationWrapper', MSRestAzureAuthStub)
+    @mock.patch.dict('os.environ', {'AZURE_CORE_USE_MSAL_MANAGED_IDENTITY': 'false'})
     def test_get_login_credentials_mi_user_assigned_with_res_id(self):
         profile = Profile(cli_ctx=DummyCli(), storage={'subscriptions': None})
         test_res_id = ('/subscriptions/{}/resourceGroups/r1/providers/Microsoft.ManagedIdentity/'
@@ -1127,9 +1244,79 @@ class TestProfile(unittest.TestCase):
         self.assertTrue(cred.token_read_count)
         self.assertTrue(cred.msi_res_id, test_res_id)
 
+    @mock.patch('azure.cli.core.auth.msal_credentials.ManagedIdentityCredential', ManagedIdentityCredentialStub)
+    def test_get_login_credentials_mi_system_assigned_msal(self):
+        profile = Profile(cli_ctx=DummyCli(), storage={'subscriptions': None})
+        consolidated = profile._normalize_properties('systemAssignedIdentity',
+                                                     [deepcopy(self.test_mi_subscription)],
+                                                     True,
+                                                     user_assigned_identity_id="MSI")
+        profile._set_subscriptions(consolidated)
+        cred, subscription_id, _ = profile.get_login_credentials()
+
+        assert subscription_id == self.test_mi_subscription_id
+        assert cred.get_token(profile._arm_scope).token == self.test_mi_access_token
+        assert cred._credential.client_id is None
+        assert cred._credential.object_id is None
+        assert cred._credential.resource_id is None
+
+    @mock.patch('azure.cli.core.auth.msal_credentials.ManagedIdentityCredential', ManagedIdentityCredentialStub)
+    def test_get_login_credentials_mi_user_assigned_client_id_msal(self):
+        profile = Profile(cli_ctx=DummyCli(), storage={'subscriptions': None})
+        consolidated = profile._normalize_properties(
+            'userAssignedIdentity',
+            [deepcopy(self.test_mi_subscription)],
+            True,
+            user_assigned_identity_id='MSIClient-{}'.format(self.test_mi_client_id)
+        )
+        profile._set_subscriptions(consolidated, secondary_key_name='name')
+        cred, subscription_id, _ = profile.get_login_credentials()
+
+        assert subscription_id == self.test_mi_subscription_id
+        assert cred.get_token(profile._arm_scope).token == self.test_mi_access_token
+        assert cred._credential.client_id == self.test_mi_client_id
+        assert cred._credential.object_id is None
+        assert cred._credential.resource_id is None
+
+    @mock.patch('azure.cli.core.auth.msal_credentials.ManagedIdentityCredential', ManagedIdentityCredentialStub)
+    def test_get_login_credentials_mi_user_assigned_object_id_msal(self):
+        profile = Profile(cli_ctx=DummyCli(), storage={'subscriptions': None})
+        consolidated = profile._normalize_properties(
+            'userAssignedIdentity',
+            [deepcopy(self.test_mi_subscription)],
+            True,
+            user_assigned_identity_id='MSIObject-{}'.format(self.test_mi_object_id)
+        )
+        profile._set_subscriptions(consolidated, secondary_key_name='name')
+        cred, subscription_id, _ = profile.get_login_credentials()
+
+        assert subscription_id == self.test_mi_subscription_id
+        assert cred.get_token(profile._arm_scope).token == self.test_mi_access_token
+        assert cred._credential.client_id is None
+        assert cred._credential.object_id == self.test_mi_object_id
+        assert cred._credential.resource_id is None
+
+    @mock.patch('azure.cli.core.auth.msal_credentials.ManagedIdentityCredential', ManagedIdentityCredentialStub)
+    def test_get_login_credentials_mi_user_assigned_resource_id_msal(self):
+        profile = Profile(cli_ctx=DummyCli(), storage={'subscriptions': None})
+        consolidated = profile._normalize_properties(
+            'userAssignedIdentity',
+            [deepcopy(self.test_mi_subscription)],
+            True,
+            user_assigned_identity_id='MSIResource-{}'.format(self.test_mi_resource_id))
+        profile._set_subscriptions(consolidated, secondary_key_name='name')
+        cred, subscription_id, _ = profile.get_login_credentials()
+
+        assert subscription_id == self.test_mi_subscription_id
+        assert cred.get_token(profile._arm_scope).token == self.test_mi_access_token
+        assert cred._credential.client_id is None
+        assert cred._credential.object_id is None
+        assert cred._credential.resource_id == self.test_mi_resource_id
+
+    @mock.patch('azure.cli.core.auth.util._now_timestamp', new=_now_timestamp_mock)
     @mock.patch('azure.cli.core.auth.identity.Identity.get_user_credential')
     def test_get_raw_token(self, get_user_credential_mock):
-        credential_mock_temp = CredentialMock()
+        credential_mock_temp = MsalCredentialStub()
         get_user_credential_mock.return_value = credential_mock_temp
         cli = DummyCli()
         # setup
@@ -1163,7 +1350,7 @@ class TestProfile(unittest.TestCase):
         creds, sub, tenant = profile.get_raw_token(resource=self.adal_resource, tenant=self.tenant_id)
 
         # verify
-        assert list(credential_mock_temp.get_token_scopes) == self.msal_scopes
+        assert credential_mock_temp.acquire_token_scopes == self.msal_scopes
 
         self.assertEqual(creds[0], 'Bearer')
         self.assertEqual(creds[1], MOCK_ACCESS_TOKEN)
@@ -1174,9 +1361,10 @@ class TestProfile(unittest.TestCase):
         self.assertIsNone(sub)
         self.assertEqual(tenant, self.tenant_id)
 
+    @mock.patch('azure.cli.core.auth.util._now_timestamp', new=_now_timestamp_mock)
     @mock.patch('azure.cli.core.auth.identity.Identity.get_service_principal_credential')
     def test_get_raw_token_for_sp(self, get_service_principal_credential_mock):
-        credential_mock_temp = CredentialMock()
+        credential_mock_temp = MsalCredentialStub()
         get_service_principal_credential_mock.return_value = credential_mock_temp
         cli = DummyCli()
         # setup
@@ -1190,7 +1378,7 @@ class TestProfile(unittest.TestCase):
         creds, sub, tenant = profile.get_raw_token(resource=self.adal_resource)
 
         # verify
-        assert list(credential_mock_temp.get_token_scopes) == self.msal_scopes
+        assert credential_mock_temp.acquire_token_scopes == self.msal_scopes
 
         self.assertEqual(creds[0], BEARER)
         self.assertEqual(creds[1], MOCK_ACCESS_TOKEN)
@@ -1215,6 +1403,7 @@ class TestProfile(unittest.TestCase):
         self.assertEqual(tenant, self.tenant_id)
 
     @mock.patch('azure.cli.core.auth.adal_authentication.MSIAuthenticationWrapper', autospec=True)
+    @mock.patch.dict('os.environ', {'AZURE_CORE_USE_MSAL_MANAGED_IDENTITY': 'false'})
     def test_get_raw_token_mi_system_assigned(self, mock_msi_auth):
         profile = Profile(cli_ctx=DummyCli(), storage={'subscriptions': None})
         consolidated = profile._normalize_properties('systemAssignedIdentity',
@@ -1252,6 +1441,134 @@ class TestProfile(unittest.TestCase):
         with self.assertRaisesRegex(CLIError, "Tenant shouldn't be specified"):
             cred, subscription_id, _ = profile.get_raw_token(resource='http://test_resource', tenant=self.tenant_id)
 
+    @mock.patch('azure.cli.core.auth.util._now_timestamp', new=_now_timestamp_mock)
+    @mock.patch('azure.cli.core.auth.msal_credentials.ManagedIdentityCredential', ManagedIdentityCredentialStub)
+    def test_get_raw_token_mi_system_assigned_msal(self):
+        profile = Profile(cli_ctx=DummyCli(), storage={'subscriptions': None})
+        consolidated = profile._normalize_properties('systemAssignedIdentity',
+                                                     [deepcopy(self.test_mi_subscription)],
+                                                     True,
+                                                     user_assigned_identity_id='MSI')
+        profile._set_subscriptions(consolidated)
+
+        credential_out = {'credential': None}
+        token_tuple, subscription_id, tenant_id = profile.get_raw_token(resource=self.adal_resource,
+                                                                        credential_out=credential_out)
+
+        cred = credential_out['credential']
+        assert cred.client_id is None
+        assert cred.object_id is None
+        assert cred.resource_id is None
+        # Verify correct scopes are passed to get_token
+        assert list(cred.get_token_scopes) == self.msal_scopes
+
+        self.assertEqual(token_tuple[0], 'Bearer')
+        self.assertEqual(token_tuple[1], self.test_mi_access_token)
+
+        # Make sure expires_on and expiresOn are set
+        self.assertEqual(token_tuple[2]['expires_on'], MOCK_EXPIRES_ON_INT)
+        self.assertEqual(token_tuple[2]['expiresOn'], MOCK_EXPIRES_ON_DATETIME)
+        self.assertEqual(subscription_id, self.test_mi_subscription_id)
+        self.assertEqual(tenant_id, self.test_mi_tenant)
+
+        # verify tenant shouldn't be specified for MSI account
+        with self.assertRaisesRegex(CLIError, "Tenant shouldn't be specified"):
+            cred, subscription_id, _ = profile.get_raw_token(resource='http://test_resource', tenant=self.tenant_id)
+
+    @mock.patch('azure.cli.core.auth.util._now_timestamp', new=_now_timestamp_mock)
+    @mock.patch('azure.cli.core.auth.msal_credentials.ManagedIdentityCredential', ManagedIdentityCredentialStub)
+    def test_get_raw_token_mi_user_assigned_client_id_msal(self):
+        profile = Profile(cli_ctx=DummyCli(), storage={'subscriptions': None})
+        consolidated = profile._normalize_properties(
+            'userAssignedIdentity',
+            [deepcopy(self.test_mi_subscription)],
+            True,
+            user_assigned_identity_id='MSIClient-{}'.format(self.test_mi_client_id)
+        )
+        profile._set_subscriptions(consolidated)
+
+        credential_out = {'credential': None}
+        token_tuple, subscription_id, tenant_id = profile.get_raw_token(resource=self.adal_resource,
+                                                                        credential_out=credential_out)
+        cred = credential_out['credential']
+        assert cred.client_id == self.test_mi_client_id
+        assert cred.object_id is None
+        assert cred.resource_id is None
+        # Verify correct scopes are passed to get_token
+        assert list(cred.get_token_scopes) == self.msal_scopes
+
+        self.assertEqual(token_tuple[0], 'Bearer')
+        self.assertEqual(token_tuple[1], self.test_mi_access_token)
+
+        # Make sure expires_on and expiresOn are set
+        self.assertEqual(token_tuple[2]['expires_on'], MOCK_EXPIRES_ON_INT)
+        self.assertEqual(token_tuple[2]['expiresOn'], MOCK_EXPIRES_ON_DATETIME)
+        self.assertEqual(subscription_id, self.test_mi_subscription_id)
+        self.assertEqual(tenant_id, self.test_mi_tenant)
+
+    @mock.patch('azure.cli.core.auth.util._now_timestamp', new=_now_timestamp_mock)
+    @mock.patch('azure.cli.core.auth.msal_credentials.ManagedIdentityCredential', ManagedIdentityCredentialStub)
+    def test_get_raw_token_mi_user_assigned_object_id_msal(self):
+        profile = Profile(cli_ctx=DummyCli(), storage={'subscriptions': None})
+        consolidated = profile._normalize_properties(
+            'userAssignedIdentity',
+            [deepcopy(self.test_mi_subscription)],
+            True,
+            user_assigned_identity_id='MSIObject-{}'.format(self.test_mi_object_id)
+        )
+        profile._set_subscriptions(consolidated)
+
+        credential_out = {'credential': None}
+        token_tuple, subscription_id, tenant_id = profile.get_raw_token(resource=self.adal_resource,
+                                                                        credential_out=credential_out)
+        cred = credential_out['credential']
+        assert cred.client_id is None
+        assert cred.object_id == self.test_mi_object_id
+        assert cred.resource_id is None
+        # Verify correct scopes are passed to get_token
+        assert list(cred.get_token_scopes) == self.msal_scopes
+
+        self.assertEqual(token_tuple[0], 'Bearer')
+        self.assertEqual(token_tuple[1], self.test_mi_access_token)
+
+        # Make sure expires_on and expiresOn are set
+        self.assertEqual(token_tuple[2]['expires_on'], MOCK_EXPIRES_ON_INT)
+        self.assertEqual(token_tuple[2]['expiresOn'], MOCK_EXPIRES_ON_DATETIME)
+        self.assertEqual(subscription_id, self.test_mi_subscription_id)
+        self.assertEqual(tenant_id, self.test_mi_tenant)
+
+    @mock.patch('azure.cli.core.auth.util._now_timestamp', new=_now_timestamp_mock)
+    @mock.patch('azure.cli.core.auth.msal_credentials.ManagedIdentityCredential', ManagedIdentityCredentialStub)
+    def test_get_raw_token_mi_user_assigned_resource_id_msal(self):
+        profile = Profile(cli_ctx=DummyCli(), storage={'subscriptions': None})
+        consolidated = profile._normalize_properties(
+            'userAssignedIdentity',
+            [deepcopy(self.test_mi_subscription)],
+            True,
+            user_assigned_identity_id='MSIResource-{}'.format(self.test_mi_resource_id)
+        )
+        profile._set_subscriptions(consolidated)
+
+        credential_out = {'credential': None}
+        token_tuple, subscription_id, tenant_id = profile.get_raw_token(resource=self.adal_resource,
+                                                                        credential_out=credential_out)
+        cred = credential_out['credential']
+        assert cred.client_id is None
+        assert cred.object_id is None
+        assert cred.resource_id == self.test_mi_resource_id
+        # Verify correct scopes are passed to get_token
+        assert list(cred.get_token_scopes) == self.msal_scopes
+
+        self.assertEqual(token_tuple[0], 'Bearer')
+        self.assertEqual(token_tuple[1], self.test_mi_access_token)
+
+        # Make sure expires_on and expiresOn are set
+        self.assertEqual(token_tuple[2]['expires_on'], MOCK_EXPIRES_ON_INT)
+        self.assertEqual(token_tuple[2]['expiresOn'], MOCK_EXPIRES_ON_DATETIME)
+        self.assertEqual(subscription_id, self.test_mi_subscription_id)
+        self.assertEqual(tenant_id, self.test_mi_tenant)
+
+    @mock.patch('azure.cli.core.auth.util._now_timestamp', new=_now_timestamp_mock)
     @mock.patch('azure.cli.core._profile.in_cloud_console', autospec=True)
     @mock.patch('azure.cli.core.auth.msal_credentials.CloudShellCredential', autospec=True)
     def test_get_raw_token_in_cloud_shell(self, cloud_shell_credential_mock, mock_in_cloud_console):
@@ -1293,7 +1610,7 @@ class TestProfile(unittest.TestCase):
         # Verify only one credential is created
         assert len(credential_instances) == 1
         # Verify correct scopes are passed to get_token
-        assert list(credential_instances[0].get_token_scopes) == self.msal_scopes
+        assert credential_instances[0].acquire_token_scopes == self.msal_scopes
 
         self.assertEqual(subscription_id, test_subscription_id)
         self.assertEqual(token_tuple[0], 'Bearer')
@@ -1565,12 +1882,6 @@ class TenantStub:  # pylint: disable=too-few-public-methods
 
 
 class TestUtils(unittest.TestCase):
-    def test_attach_token_tenant_v2016_06_01(self):
-        from azure.mgmt.resource.subscriptions.v2016_06_01.models import Subscription
-        subscription = Subscription()
-        _attach_token_tenant(subscription, "token_tenant_1")
-        self.assertEqual(subscription.tenant_id, "token_tenant_1")
-        self.assertFalse(hasattr(subscription, "home_tenant_id"))
 
     def test_attach_token_tenant_v2022_12_01(self):
         from azure.mgmt.resource.subscriptions.v2022_12_01.models import Subscription
