@@ -8,18 +8,13 @@ from unittest import mock
 import os
 import unittest
 
+import urllib.request as http_client_t
+from urllib.error import HTTPError
+
 from applicationinsights.channel import SynchronousSender
 
-try:
-    # Python 2.x
-    import urllib2 as http_client_t
-    from urllib2 import HTTPError
-except ImportError:
-    # Python 3.x
-    import urllib.request as http_client_t
-    from urllib.error import HTTPError
 
-from azure.cli.telemetry.components.telemetry_client import (CliTelemetryClient, _NoRetrySender, http_client_t)
+from azure.cli.telemetry.components.telemetry_client import CliTelemetryClient, _NoRetrySender
 
 TEST_RESOURCE_FOLDER = os.path.join(os.path.dirname(__file__), 'resources')
 
@@ -28,7 +23,7 @@ class _TestSender(SynchronousSender):
     instances = []
 
     def __init__(self):
-        super(_TestSender, self).__init__()
+        super().__init__()
         _TestSender.instances.append(self)
 
         self.data = []
