@@ -4,9 +4,11 @@
 # --------------------------------------------------------------------------------------------
 
 import os
+import re
 from knack.util import CLIError
 from knack.log import get_logger
 from azure.cli.core.azclierror import FileOperationError, InvalidArgumentValueError
+from ._constants import ACR_NAME_VALIDATION_REGEX
 
 BAD_REPO_FQDN = "The positional parameter 'repo_id' must be a fully qualified repository specifier such"\
                 " as 'myregistry.azurecr.io/hello-world'."
@@ -16,6 +18,7 @@ BAD_PERM_REPO_FQDN = "The positional parameter 'perm_repo_id' must be a fully qu
 BAD_MANIFEST_FQDN = "The positional parameter 'manifest_id' must be a fully qualified"\
                     " manifest specifier such as 'myregistry.azurecr.io/hello-world:latest' or"\
                     " 'myregistry.azurecr.io/hello-world@sha256:abc123'."
+BAD_REGISTRY_NAME = "Registry names may contain only alpha numeric characters and must be between 5 and 50 characters"
 
 logger = get_logger(__name__)
 
@@ -103,14 +106,31 @@ def validate_retention_days(namespace):
 def validate_registry_name(cmd, namespace):
     """Omit login server endpoint suffix."""
     registry = namespace.registry_name
+    if registry is None:
+        return
     suffixes = cmd.cli_ctx.cloud.suffixes
+    dnl_hash = registry.find("-")
+
+    if dnl_hash > 0:
+        logger.warning(
+            "Registry name is %s. The following suffix '%s' is automatically omitted.",
+            registry[:dnl_hash],
+            registry[dnl_hash:])
+        namespace.registry_name = registry[:dnl_hash]
     # Some clouds do not define 'acr_login_server_endpoint' (e.g. AzureGermanCloud)
-    if registry and hasattr(suffixes, 'acr_login_server_endpoint'):
+    elif hasattr(suffixes, 'acr_login_server_endpoint'):
         acr_suffix = suffixes.acr_login_server_endpoint
         pos = registry.find(acr_suffix)
         if pos > 0:
-            logger.warning("The login server endpoint suffix '%s' is automatically omitted.", acr_suffix)
+            logger.warning("Registry name is %s. The following suffix '%s' is automatically omitted.",
+                           registry[:pos],
+                           acr_suffix)
             namespace.registry_name = registry[:pos]
+            registry = registry[:pos]
+
+    registry = namespace.registry_name
+    if not re.match(ACR_NAME_VALIDATION_REGEX, registry):
+        raise InvalidArgumentValueError(BAD_REGISTRY_NAME)
 
 
 def validate_expiration_time(namespace):
