@@ -4,11 +4,13 @@
 # --------------------------------------------------------------------------------------------
 
 from azure.cli.testsdk import ScenarioTest, StorageAccountPreparer, ResourceGroupPreparer, record_only
+from azure.cli.testsdk.scenario_tests import AllowLargeResponse
 
 
 class AcrConnectedRegistryCommandsTests(ScenarioTest):
 
     @ResourceGroupPreparer()
+    @AllowLargeResponse(size_kb=99999)
     def test_acr_connectedregistry(self, resource_group):
         # Agentpool prerequisites for connected registry testing
         crName = 'connectedregistry'
@@ -37,9 +39,12 @@ class AcrConnectedRegistryCommandsTests(ScenarioTest):
             'defaultSyncSchedule': '* * * * *',
             'syncWindow': 'PT4H',
             'notificationStr': 'hello-world:tag:push',
-            'notificationStr2': '*:*'
+            'notificationStr2': '*:*',
+            'garbage_collection_enabled_true': True,
+            'garbage_collection_enabled_false': False,
+            'garbage_collection_schedule': '0 0 */2 * *',
         })
-        # Create Registr and enable data endpoint
+        # Create Registry and enable data endpoint
         self.cmd('acr create -n {registry_name} -g {rg} -l {rg_loc} --sku {sku}',
                  checks=[self.check('name', '{registry_name}'),
                          self.check('location', '{rg_loc}'),
@@ -51,12 +56,13 @@ class AcrConnectedRegistryCommandsTests(ScenarioTest):
                  checks=self.check('dataEndpointEnabled', True))
 
         # Create a default connected registry.
-        self.cmd('acr connected-registry create -n {cr_name} -r {registry_name} -m ReadWrite --repository {repo_1} {repo_2} {repo_3}',
+        self.cmd('acr connected-registry create -n {cr_name} -r {registry_name} -m ReadWrite --repository {repo_1} {repo_2} {repo_3} --gc-enabled {garbage_collection_enabled_false}',
                  checks=[self.check('name', '{cr_name}'),
                          self.check('mode', 'ReadWrite'),
                          self.check('logging.logLevel', 'Information'),
                          self.check('provisioningState', 'Succeeded'),
-                         self.check('resourceGroup', '{rg}')])
+                         self.check('resourceGroup', '{rg}'),
+                         self.check('garbageCollection.enabled', False)])
 
         # Create a custom connected-registry with a previously created token.
         self.cmd('acr token create -r {registry_name} -n {syncToken} --repository {repo_1} content/read metadata/read --gateway {root_name} config/read config/write message/read message/write --no-passwords')
@@ -98,13 +104,14 @@ class AcrConnectedRegistryCommandsTests(ScenarioTest):
 
         # Update the connected registry
         self.cmd('acr token create -r {registry_name} -n {clientToken2} --repository {repo_2} metadata/read --no-passwords')
-        self.cmd('acr connected-registry update -n {root_name} -r {registry_name} --log-level Information -s "{defaultSyncSchedule}" --remove-client-tokens {clientToken} --add-client-tokens {clientToken2} --add-notifications {notificationStr2} --remove-notifications {notificationStr}',
+        self.cmd('acr connected-registry update -n {root_name} -r {registry_name} --log-level Information -s "{defaultSyncSchedule}"  --remove-client-tokens {clientToken} --add-client-tokens {clientToken2} --add-notifications {notificationStr2} --remove-notifications {notificationStr} --gc-enabled {garbage_collection_enabled_true} --gc-schedule "{garbage_collection_schedule}"',
                  checks=[self.check('name', '{root_name}'),
                          self.check('logging.logLevel', 'Information'),
                          self.check('parent.syncProperties.schedule', '{defaultSyncSchedule}'),
                          self.check('parent.syncProperties.syncWindow', 'None'),
                          self.check('resourceGroup', '{rg}'),
-                         self.check('notificationsList[0]', '{notificationStr2}')])
+                         self.check('notificationsList[0]', '{notificationStr2}'),
+                         self.check('garbageCollection.schedule', '{garbage_collection_schedule}')])
 
         # List client tokens
         self.cmd('acr connected-registry list-client-tokens -n {root_name} -r {registry_name}',
@@ -156,4 +163,4 @@ class AcrConnectedRegistryCommandsTests(ScenarioTest):
         self.cmd('acr connected-registry delete -n {child_name} -r {registry_name} -y')
 
         # Delete registry
-        self.cmd('acr delete -n {registry_name} -g {rg} -y')
+        self.cmd('acr delete -n {registry_name} -g {rg} -y')
\ No newline at end of file
