@@ -8,6 +8,8 @@ import shutil
 import tempfile
 import unittest
 from unittest import mock
+import datetime
+from dateutil.parser import parse
 
 import yaml
 from azure.cli.command_modules.acs._consts import (
@@ -19,12 +21,18 @@ from azure.cli.command_modules.acs._consts import (
 from azure.cli.command_modules.acs.custom import (
     _get_command_context,
     _update_addons,
+    aks_stop,
     k8s_install_kubectl,
     k8s_install_kubelogin,
     merge_kubernetes_configurations,
+    _update_upgrade_settings,
+)
+from azure.cli.command_modules.acs.managed_cluster_decorator import (
+    AKSManagedClusterModels,
 )
 from azure.cli.command_modules.acs.tests.latest.mocks import (
     MockCLI,
+    MockClient,
     MockCmd,
     MockUrlretrieveUrlValidator,
 )
@@ -33,14 +41,19 @@ from azure.cli.command_modules.acs.tests.latest.utils import (
     get_test_data_file_path,
 )
 from azure.cli.core.util import CLIError
+from azure.cli.core.profiles import ResourceType
 from azure.mgmt.containerservice.v2020_03_01.models import (
     ManagedClusterAddonProfile,
 )
+from azure.cli.core.azclierror import (
+    InvalidArgumentValueError,
+)
 
 
 class AcsCustomCommandTest(unittest.TestCase):
     def setUp(self):
         self.cli = MockCLI()
+        self.models = AKSManagedClusterModels(MockCmd(self.cli), ResourceType.MGMT_CONTAINERSERVICE)
 
     def test_merge_credentials_non_existent(self):
         self.assertRaises(CLIError, merge_kubernetes_configurations, 'non', 'existent', False)
@@ -677,6 +690,136 @@ class AcsCustomCommandTest(unittest.TestCase):
         finally:
             shutil.rmtree(temp_dir)
 
+    @mock.patch('azure.cli.command_modules.acs.addonconfiguration.get_rg_location', return_value='eastus')
+    @mock.patch('azure.cli.command_modules.acs.addonconfiguration.get_resource_groups_client', autospec=True)
+    @mock.patch('azure.cli.command_modules.acs.addonconfiguration.get_resources_client', autospec=True)
+    def test_update_upgrade_settings(self, rg_def, get_resource_groups_client, get_resources_client):
+        instance = mock.MagicMock()
+
+        # Should not update mc if unset
+        instance.upgrade_settings = None
+        instance = _update_upgrade_settings(MockCmd(self.cli), instance, enable_force_upgrade=False, disable_force_upgrade=False, upgrade_override_until=None)
+        self.assertIsNone(instance.upgrade_settings)
+
+        instance.upgrade_settings = self.models.ClusterUpgradeSettings(
+            override_settings = self.models.UpgradeOverrideSettings(
+                force_upgrade = True,
+                until=parse("2023-04-01T13:00:00Z")
+            )
+        )
+        instance = _update_upgrade_settings(MockCmd(self.cli), instance, enable_force_upgrade=False, disable_force_upgrade=False, upgrade_override_until=None)
+        self.assertTrue(instance.upgrade_settings.override_settings.force_upgrade)
+        self.assertEqual(instance.upgrade_settings.override_settings.until, parse("2023-04-01T13:00:00Z"))
+
+        # force_upgrade True
+        instance.upgrade_settings = None
+        instance = _update_upgrade_settings(MockCmd(self.cli), instance, enable_force_upgrade=True, disable_force_upgrade=False, upgrade_override_until=None)
+        self.assertTrue(instance.upgrade_settings.override_settings.force_upgrade)
+        self.assertGreater(instance.upgrade_settings.override_settings.until.timestamp(), (datetime.datetime.utcnow() + datetime.timedelta(days=2)).timestamp())
+        self.assertLess(instance.upgrade_settings.override_settings.until.timestamp(), (datetime.datetime.utcnow() + datetime.timedelta(days=4)).timestamp())
+
+        instance.upgrade_settings = self.models.ClusterUpgradeSettings(
+            override_settings = self.models.UpgradeOverrideSettings(
+                force_upgrade = False
+            )
+        )
+        instance = _update_upgrade_settings(MockCmd(self.cli), instance, enable_force_upgrade=True, disable_force_upgrade=False, upgrade_override_until=None)
+        self.assertTrue(instance.upgrade_settings.override_settings.force_upgrade)
+        self.assertGreater(instance.upgrade_settings.override_settings.until.timestamp(), (datetime.datetime.utcnow() + datetime.timedelta(days=2)).timestamp())
+        self.assertLess(instance.upgrade_settings.override_settings.until.timestamp(), (datetime.datetime.utcnow() + datetime.timedelta(days=4)).timestamp())
+
+        # force_upgrade False
+        instance.upgrade_settings = None
+        instance = _update_upgrade_settings(MockCmd(self.cli), instance, enable_force_upgrade=False, disable_force_upgrade=True, upgrade_override_until=None)
+        self.assertFalse(instance.upgrade_settings.override_settings.force_upgrade)
+        self.assertIsNone(instance.upgrade_settings.override_settings.until)
+
+        instance.upgrade_settings = None
+        instance.upgrade_settings = self.models.ClusterUpgradeSettings(
+            override_settings = self.models.UpgradeOverrideSettings(
+                force_upgrade = True
+            )
+        )
+        instance = _update_upgrade_settings(MockCmd(self.cli), instance, enable_force_upgrade=False, disable_force_upgrade=True, upgrade_override_until=None)
+        self.assertFalse(instance.upgrade_settings.override_settings.force_upgrade)
+        self.assertIsNone(instance.upgrade_settings.override_settings.until)
+
+        # Update util
+        instance.upgrade_settings = None
+        instance = _update_upgrade_settings(MockCmd(self.cli), instance, enable_force_upgrade=False, disable_force_upgrade=False, upgrade_override_until="2024-01-01T13:00:00Z")
+        self.assertIsNone(instance.upgrade_settings.override_settings.force_upgrade)
+        self.assertEqual(instance.upgrade_settings.override_settings.until, parse("2024-01-01T13:00:00Z"))
+        
+        instance.upgrade_settings = None
+        instance.upgrade_settings = self.models.ClusterUpgradeSettings(
+            override_settings = self.models.UpgradeOverrideSettings(
+                until=parse("2023-04-01T13:00:00Z")
+            )
+        )
+        instance = _update_upgrade_settings(MockCmd(self.cli), instance, enable_force_upgrade=False, disable_force_upgrade=False, upgrade_override_until="2024-01-01T13:00:00Z")
+        self.assertIsNone(instance.upgrade_settings.override_settings.force_upgrade)
+        self.assertEqual(instance.upgrade_settings.override_settings.until, parse("2024-01-01T13:00:00Z"))
+
+        with self.assertRaises(InvalidArgumentValueError):
+            _update_upgrade_settings(MockCmd(self.cli), instance, enable_force_upgrade=False, disable_force_upgrade=False, upgrade_override_until="abc")
+
+         # Set both force_upgrade and until 
+        instance.upgrade_settings = None
+        instance = _update_upgrade_settings(MockCmd(self.cli), instance, enable_force_upgrade=True, disable_force_upgrade=False, upgrade_override_until="2024-01-01T13:00:00Z")
+        self.assertTrue(instance.upgrade_settings.override_settings.force_upgrade)
+        self.assertEqual(instance.upgrade_settings.override_settings.until, parse("2024-01-01T13:00:00Z"))
+        
+        instance.upgrade_settings = self.models.ClusterUpgradeSettings(
+            override_settings = self.models.UpgradeOverrideSettings(
+                force_upgrade = True,
+                until=parse("2023-04-01T13:00:00Z")
+            )
+        )
+        instance = _update_upgrade_settings(MockCmd(self.cli), instance, enable_force_upgrade=False, disable_force_upgrade=True, upgrade_override_until="2024-01-01T13:00:00Z")
+        self.assertFalse(instance.upgrade_settings.override_settings.force_upgrade)
+        self.assertEqual(instance.upgrade_settings.override_settings.until, parse("2024-01-01T13:00:00Z"))
+
+        instance.upgrade_settings = self.models.ClusterUpgradeSettings(
+            override_settings = self.models.UpgradeOverrideSettings(
+                force_upgrade = False,
+                until=parse("2023-04-01T13:00:00Z")
+            )
+        )
+        instance = _update_upgrade_settings(MockCmd(self.cli), instance, enable_force_upgrade=True, disable_force_upgrade=False, upgrade_override_until="2024-01-01T13:00:00Z")
+        self.assertTrue(instance.upgrade_settings.override_settings.force_upgrade)
+        self.assertEqual(instance.upgrade_settings.override_settings.until, parse("2024-01-01T13:00:00Z"))
+
+class TestAKSCommand(unittest.TestCase):
+    def setUp(self):
+        self.cli_ctx = MockCLI()
+        self.cmd = MockCmd(self.cli_ctx)
+        self.models = AKSManagedClusterModels(self.cmd, ResourceType.MGMT_CONTAINERSERVICE)
+        self.client = MockClient()
+
+    def test_aks_stop(self):
+        # public cluster: call begin_stop
+        mc_1 = self.models.ManagedCluster(location="test_location")
+        self.client.get = mock.Mock(
+            return_value=mc_1
+        )
+        self.client.begin_stop = mock.Mock(
+            return_value=None
+        )
+        self.assertEqual(aks_stop(self.cmd, self.client, "rg", "name"), None)
+
+        # private cluster: call begin_stop
+        mc_2 = self.models.ManagedCluster(location="test_location")
+        api_server_access_profile = self.models.ManagedClusterAPIServerAccessProfile()
+        api_server_access_profile.enable_private_cluster = True
+        mc_2.api_server_access_profile = api_server_access_profile
+        self.client.get = mock.Mock(
+            return_value=mc_2
+        )
+        self.client.begin_stop = mock.Mock(
+            return_value=None
+        )
+        self.assertEqual(aks_stop(self.cmd, self.client, "rg", "name", False), None)
+
 
 class TestRunCommand(unittest.TestCase):
     def test_get_command_context_invalid_file(self):
