@@ -366,7 +366,7 @@ class FeaturePercentileAllocation:
 
     :ivar str variant:
         The name of the variant to use if the calculated percentile for the current user falls in the provided range.
-    :ivar number from_:
+    :ivar number from:
         The lower end of the percentage range for which this variant will be used.
     :ivar number to:
         The upper end of the percentage range for which this variant will be used.
@@ -374,7 +374,7 @@ class FeaturePercentileAllocation:
 
     def __init__(self, variant, from_, to):
         self.variant = variant
-        self.from_ = from_
+        setattr(self, "from", from_)
         self.to = to
 
     @classmethod
@@ -435,7 +435,7 @@ class FeaturePercentileAllocation:
     def __repr__(self):
         feature_percentile_allocation = {
             FeatureFlagConstants.VARIANT: self.variant,
-            FeatureFlagConstants.FROM: self.from_,
+            FeatureFlagConstants.FROM: getattr(self, "from"),
             FeatureFlagConstants.TO: self.to,
         }
 
@@ -906,14 +906,15 @@ def map_keyvalue_to_featureflagvalue(keyvalue):
                 FeatureFlagConstants.REQUIREMENT_TYPE, None
             )
             if requirement_type:
-                if requirement_type.lower() not in (
-                    FeatureFlagConstants.REQUIREMENT_TYPE_ALL,
-                    FeatureFlagConstants.REQUIREMENT_TYPE_ANY,
-                ):
+                # Requirement type is case insensitive.
+                if requirement_type.lower() == FeatureFlagConstants.REQUIREMENT_TYPE_ALL.lower():
+                    conditions[FeatureFlagConstants.REQUIREMENT_TYPE] = FeatureFlagConstants.REQUIREMENT_TYPE_ALL
+                elif requirement_type.lower() == FeatureFlagConstants.REQUIREMENT_TYPE_ANY.lower():
+                    conditions[FeatureFlagConstants.REQUIREMENT_TYPE] = FeatureFlagConstants.REQUIREMENT_TYPE_ANY
+                else:
                     raise ValidationError(
-                        f"Feature '{feature_name}' must have an any/all requirement type."
+                        f"Feature '{feature_name}' must have an Any/All requirement type."
                     )
-                conditions[FeatureFlagConstants.REQUIREMENT_TYPE] = requirement_type
 
             # Backend returns conditions: {client_filters: None} for flags with no conditions.
             # No need to write empty conditions to key-values.
