@@ -18,6 +18,8 @@ short-summary: Create an App Configuration.
 examples:
   - name: Create an App Configuration store with name, location, sku, tags and resource group.
     text: az appconfig create -g MyResourceGroup -n MyAppConfiguration -l westus --sku Standard --tags key1=value1 key2=value2
+  - name: Create an App Configuration store with Developer sku
+    text: az appconfig create -g MyResourceGroup -n MyAppConfiguration -l westus --sku Developer
   - name: Create a premium sku App Configuration store with a replica
     text: az appconfig create -g MyResourceGroup -n MyAppConfiguration -l westus --sku Premium --replica-name MyReplica --replica-location eastus
   - name: Create a premium sku App Configuration store without a replica
@@ -153,7 +155,7 @@ helps['appconfig kv export'] = """
 type: command
 short-summary: Export configurations to another place from your App Configuration store.
 examples:
-  - name: Export all keys and feature flags with label test to a json file.
+  - name: Export all keys and feature flags with label test to a json file. To use the Microsoft Feature Management schema when exporting feature flags to a file, set the environment variable AZURE_APPCONFIG_FM_COMPATIBLE to False.
     text: az appconfig kv export -n MyAppConfiguration --label test -d file --path D:/abc.json --format json
   - name: Export all keys with null label to an App Service application.
     text: az appconfig kv export -n MyAppConfiguration -d appservice --appservice-account MyAppService
