@@ -78,6 +78,23 @@ class AppConfigFeatureScenarioTest(ScenarioTest):
                          self.check('conditions.client_filters', []),
                          self.check('conditions.requirement_type', updated_requirement_type)])
 
+        # update an existing feature flag entry with requirement type "all" (case-insensitive input, should be stored as "All")
+        case_sensitive_requirement_type = FeatureFlagConstants.REQUIREMENT_TYPE_ALL
+
+        self.kwargs.update({
+            'description': updated_entry_description,
+            'requirement_type': "all"
+        })
+        self.cmd('appconfig feature set -n {config_store_name} --feature {feature} --label {label} --description "{description}" --requirement-type {requirement_type} -y',
+             checks=[self.check('locked', default_locked),
+                 self.check('name', entry_feature),
+                 self.check('key', internal_feature_key),
+                 self.check('description', updated_entry_description),
+                 self.check('label', entry_label),
+                 self.check('state', default_state),
+                 self.check('conditions.client_filters', []),
+                 self.check('conditions.requirement_type', case_sensitive_requirement_type)])
+
         # add a new label - this should create a new KV in the config store
         updated_label = 'v2'
         self.kwargs.update({
