@@ -10,8 +10,8 @@ from azure.cli.core.util import sdk_no_wait, send_raw_request
 from azure.cli.core.commands import LongRunningOperation
 from azure.cli.core.azclierror import (ResourceNotFoundError, ValidationError, RequiredArgumentMissingError,
                                        InvalidArgumentValueError, UnauthorizedError)
+from azure.mgmt.core.tools import parse_resource_id
 from knack.log import get_logger
-from msrestazure.tools import parse_resource_id
 from urllib.parse import urlparse
 import uuid
 from datetime import datetime, timedelta
@@ -299,11 +299,13 @@ def set_staticsite_app_settings(cmd, name, setting_pairs, resource_group_name=No
         app_settings.properties[k] = v
 
     if not environment_name:
-        return client.create_or_update_static_site_app_settings(
+        result = client.create_or_update_static_site_app_settings(
             resource_group_name, name, app_settings=app_settings)
+    else:
+        result = client.create_or_update_static_site_build_app_settings(
+            resource_group_name, name, environment_name, app_settings=app_settings)
 
-    return client.create_or_update_static_site_build_app_settings(
-        resource_group_name, name, environment_name, app_settings=app_settings)
+    return _redact_appsettings(result)
 
 
 def delete_staticsite_app_settings(cmd, name, setting_names, resource_group_name=None, environment_name=None):
@@ -320,11 +322,20 @@ def delete_staticsite_app_settings(cmd, name, setting_names, resource_group_name
             logger.warning("key '%s' not found in app settings", key)
 
     if not environment_name:
-        return client.create_or_update_static_site_app_settings(
+        result = client.create_or_update_static_site_app_settings(
             resource_group_name, name, app_settings=app_settings)
+    else:
+        result = client.create_or_update_static_site_build_app_settings(
+            resource_group_name, name, environment_name, app_settings=app_settings)
 
-    return client.create_or_update_static_site_build_app_settings(
-        resource_group_name, name, environment_name, app_settings=app_settings)
+    return _redact_appsettings(result)
+
+
+def _redact_appsettings(payload):
+    logger.warning('App settings have been redacted. Use `az staticwebapp appsettings list` to view.')
+    for x in payload.properties:
+        payload.properties[x] = None
+    return payload
 
 
 def list_staticsite_users(cmd, name, resource_group_name=None, authentication_provider='all'):
@@ -520,7 +531,7 @@ def delete_staticsite(cmd, name, resource_group_name=None, no_wait=False):
 
 def _parse_pair(pair, delimiter):
     if delimiter not in pair:
-        InvalidArgumentValueError("invalid format of pair {0}".format(pair))
+        raise InvalidArgumentValueError("invalid format of pair {0}".format(pair))
 
     index = pair.index(delimiter)
     return pair[:index], pair[1 + index:]
