@@ -8,7 +8,8 @@ import random
 from base64 import b64decode
 import textwrap
 
-from azure.core.exceptions import HttpResponseError
+from azure.core.exceptions import HttpResponseError, \
+    ResourceNotFoundError as CoreResourceNotFoundError
 from azure.mgmt.core.tools import resource_id, parse_resource_id
 import azure.mgmt.redhatopenshift.models as openshiftcluster
 
@@ -462,11 +463,14 @@ def get_network_resources_from_subnets(cli_ctx, subnets, fail, oc):
                     Please retry, if issue persists: raise azure support ticket""")
             logger.info("Failed to validate subnet '%s'", sn)
 
-        subnet = subnet_show(cli_ctx=cli_ctx)(command_args={
-            "name": sid['resource_name'],
-            "vnet_name": sid['name'],
-            "resource_group": sid['resource_group']
-        })
+        try:
+            subnet = subnet_show(cli_ctx=cli_ctx)(command_args={
+                "name": sid['resource_name'],
+                "vnet_name": sid['name'],
+                "resource_group": sid['resource_group']}
+            )
+        except CoreResourceNotFoundError:
+            continue
 
         if subnet.get("routeTable", None):
             subnet_resources.add(subnet["routeTable"]["id"])
