@@ -3,6 +3,8 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
+# pylint: disable=line-too-long
+
 from datetime import datetime
 from azure.cli.core.azclierror import RequiredArgumentMissingError, MutuallyExclusiveArgumentError, \
     ArgumentUsageError, InvalidArgumentValueError
@@ -53,10 +55,10 @@ def validate_wl_restore(item, item_type, restore_mode, recovery_mode):
     #        operation. Correct value should be - {}.
     #        """.format(item.properties.workload_type))
 
-    if item_type is None or item_type.lower() not in ['sql', 'saphana']:
+    if item_type is None or item_type.lower() not in ['sql', 'saphana', 'sapase']:
         raise InvalidArgumentValueError("""
             The item_type specified in recovery config file is incorrect. Please correct it and retry the
-            operation. Allowed values are: 'SQL', 'SAPHana'.
+            operation. Allowed values are: 'SQL', 'SAPHana', 'SAPAse'.
             """)
 
     if item_type.lower() not in item.properties.workload_type.lower():
@@ -71,7 +73,7 @@ def validate_wl_restore(item, item_type, restore_mode, recovery_mode):
             operation. Allowed values are: 'OriginalLocation', 'AlternateLocation'.
             """)
 
-    if recovery_mode is not None and recovery_mode != 'FileRecovery':
+    if recovery_mode is not None and recovery_mode not in ['FileRecovery', 'SnapshotAttachAndRecover', 'SnapshotAttach']:
         raise InvalidArgumentValueError("""
             The recovery_mode specified in recovery config file is incorrect. Please correct it and retry the
             operation.
@@ -98,19 +100,28 @@ def validate_crr(target_rg_id, rehydration_priority):
         raise MutuallyExclusiveArgumentError("Archive restore isn't supported for secondary region.")
 
 
-def validate_czr(backup_config_response, recovery_point):
+def validate_czr(backup_config_response, recovery_point, use_secondary_region):
     backup_storage_redundancy = backup_config_response.properties.storage_type
     cross_region_restore_flag = backup_config_response.properties.cross_region_restore_flag
     if (cross_region_restore_flag or backup_storage_redundancy == StorageType.ZONE_REDUNDANT):
-        if recovery_point.tier_type is not None and recovery_point.tier_type == "VaultStandard":
-            if recovery_point.properties.zones is None:
-                raise ArgumentUsageError("""
-                Please ensure that the recovery point is zone pinned or remove --target-zone argument.
-                """)
+        if recovery_point.tier_type is not None and (
+           recovery_point.tier_type == "VaultStandard" or
+           recovery_point.tier_type == "SnapshotAndVaultStandard"):
+            if backup_storage_redundancy != StorageType.ZONE_REDUNDANT:
+                if recovery_point.properties.zones is None:
+                    raise ArgumentUsageError("""
+                    Please ensure that either the vault storage redundancy is ZoneRedundant or the recovery
+                    point is zone pinned, or remove --target-zone argument.
+                    """)
+                if not use_secondary_region:
+                    raise ArgumentUsageError("""
+                    Please ensure that either the vault storage redundancy is ZoneRedundant or the restore
+                    is not to the primary region, or remove --target-zone argument.
+                    """)
         else:
             raise ArgumentUsageError("""
-            Please ensure that the given RP tier type is 'VaultStandard' or remove --target-zone argument.
-            """)
+            Please ensure that the given RP tier type is either 'VaultStandard' or 'SnapshotAndVaultStandard',
+            or remove --target-zone argument.""")
     else:
         raise ArgumentUsageError("""
         Please ensure either the vault storage redundancy is ZoneRedundant or the vault has CRR enabled or try
