@@ -4,6 +4,7 @@
 # --------------------------------------------------------------------------------------------
 from datetime import datetime, timedelta, timezone
 import azure.cli.command_modules.backup.custom_help as helper
+# pylint: disable=too-many-locals
 # pylint: disable=import-error
 # pylint: disable=unused-argument
 
@@ -23,6 +24,9 @@ from azure.cli.core.azclierror import ArgumentUsageError
 from azure.mgmt.recoveryservicesbackup.activestamp import RecoveryServicesBackupClient
 from azure.cli.core.commands.client_factory import get_mgmt_service_client
 
+from knack.log import get_logger
+logger = get_logger(__name__)
+
 fabric_name = "Azure"
 backup_management_type = "AzureStorage"
 workload_type = "AzureFileShare"
@@ -65,8 +69,9 @@ def enable_for_AzureFileShare(cmd, client, resource_group_name, vault_name, afs_
                                            source_resource_id=storage_account.properties.container_id,
                                            workload_type="AzureFileShare")
         param = ProtectionContainerResource(properties=properties)
-        result = protection_containers_client.register(vault_name, resource_group_name, fabric_name,
-                                                       storage_account.name, param, cls=helper.get_pipeline_response)
+        result = protection_containers_client.begin_register(vault_name, resource_group_name, fabric_name,
+                                                             storage_account.name, param, polling=False,
+                                                             cls=helper.get_pipeline_response).result()
         helper.track_register_operation(cmd.cli_ctx, result, vault_name, resource_group_name, storage_account.name)
 
     protectable_item = _get_protectable_item_for_afs(cmd.cli_ctx, vault_name, resource_group_name, afs_name,
@@ -171,20 +176,22 @@ def _try_get_protectable_item_for_afs(cli_ctx, vault_name, resource_group_name,
 
 def restore_AzureFileShare(cmd, client, resource_group_name, vault_name, rp_name, item, restore_mode,
                            resolve_conflict, restore_request_type, source_file_type=None, source_file_path=None,
-                           target_storage_account_name=None, target_file_share_name=None, target_folder=None):
+                           target_storage_account_name=None, target_file_share_name=None, target_folder=None,
+                           target_resource_group_name=None, tenant_id=None):
 
     container_uri = helper.get_protection_container_uri_from_id(item.id)
     item_uri = helper.get_protected_item_uri_from_id(item.id)
 
-    sa_name = item.properties.container_name
+    # sa_name = item.properties.container_name
 
     afs_restore_request = AzureFileShareRestoreRequest()
     target_details = None
 
     afs_restore_request.copy_options = resolve_conflict
     afs_restore_request.recovery_type = restore_mode
-    afs_restore_request.source_resource_id = _get_storage_account_id(cmd.cli_ctx, sa_name.split(';')[-1],
-                                                                     sa_name.split(';')[-2])
+    afs_restore_request.source_resource_id = _get_storage_account_id(cmd.cli_ctx,
+                                                                     item.properties.container_name.split(';')[-1],
+                                                                     item.properties.container_name.split(';')[-2])
     afs_restore_request.restore_request_type = restore_request_type
 
     restore_file_specs = None
@@ -201,7 +208,11 @@ def restore_AzureFileShare(cmd, client, resource_group_name, vault_name, rp_name
                                                        target_folder_path=target_folder))
 
     if restore_mode == "AlternateLocation":
-        target_sa_name, target_sa_rg = helper.get_resource_name_and_rg(resource_group_name, target_storage_account_name)
+        if target_resource_group_name is None:
+            target_resource_group_name = resource_group_name
+        target_sa_name, target_sa_rg = helper.get_resource_name_and_rg(
+            target_resource_group_name,
+            target_storage_account_name)
         target_details = TargetAFSRestoreInfo()
         target_details.name = target_file_share_name
         target_details.target_resource_id = _get_storage_account_id(cmd.cli_ctx, target_sa_name, target_sa_rg)
@@ -211,6 +222,16 @@ def restore_AzureFileShare(cmd, client, resource_group_name, vault_name, rp_name
 
     trigger_restore_request = RestoreRequestResource(properties=afs_restore_request)
 
+    if helper.has_resource_guard_mapping(cmd.cli_ctx, resource_group_name, vault_name, "RecoveryServicesRestore"):
+        # Cross Tenant scenario
+        if tenant_id is not None:
+            client = get_mgmt_service_client(cmd.cli_ctx, RecoveryServicesBackupClient,
+                                             aux_tenants=[tenant_id]).restores
+        trigger_restore_request.properties.resource_guard_operation_requests = [
+            helper.get_resource_guard_operation_request(
+                cmd.cli_ctx, resource_group_name, vault_name, "RecoveryServicesRestore")]
+
+    # Trigger restore
     result = client.begin_trigger(vault_name, resource_group_name, fabric_name, container_uri, item_uri, rp_name,
                                   trigger_restore_request, cls=helper.get_pipeline_response, polling=False).result()
 
@@ -227,9 +248,9 @@ def list_recovery_points(cmd, client, resource_group_name, vault_name, item, sta
             Please either remove the flag or query for any other backup-management-type.
             """)
 
-    if is_ready_for_move is not None or target_tier is not None or tier is not None:
+    if is_ready_for_move is not None or target_tier is not None:
         raise ArgumentUsageError("""Invalid argument has been passed. --is-ready-for-move true, --target-tier
-        and --tier flags are not supported for --backup-management-type AzureStorage.""")
+        are not supported for --backup-management-type AzureStorage.""")
 
     if recommended_for_archive is not None:
         raise ArgumentUsageError("""--recommended-for-archive is supported by AzureIaasVM backup management
@@ -252,11 +273,57 @@ def list_recovery_points(cmd, client, resource_group_name, vault_name, item, sta
     recovery_points = client.list(vault_name, resource_group_name, fabric_name, container_uri, item_uri, filter_string)
     paged_recovery_points = helper.get_list_from_paged_response(recovery_points)
 
+    if tier:
+        filtered_recovery_points = []
+
+        for rp in paged_recovery_points:
+            # Prepare to collect tier types
+            rp_tier_types = []
+
+            # Safely grab additional_properties
+            additional_props = getattr(rp.properties, 'additional_properties', {})
+            if not isinstance(additional_props, dict):
+                continue
+
+            # Get details list
+            tier_details_list = additional_props.get("recoveryPointTierDetails", [])
+            if not isinstance(tier_details_list, list):
+                continue
+
+            for detail in tier_details_list:
+                if not isinstance(detail, dict):
+                    continue
+                rp_type = detail.get("type")
+                if rp_type:
+                    rp_tier_types.append(rp_type)
+
+            # Map types to a tier
+            if 'InstantRP' in rp_tier_types and 'HardenedRP' in rp_tier_types:
+                rp_tier = 'SnapshotAndVaultStandard'
+            elif 'InstantRP' in rp_tier_types:
+                rp_tier = 'Snapshot'
+            elif 'HardenedRP' in rp_tier_types:
+                rp_tier = 'VaultStandard'
+            else:
+                logger.warning(
+                    "Warning: Unrecognized Recovery Point tier received."
+                    "If you see this message, please contact Microsoft Support."
+                    "The recognized tiers for AzureFileShare are: 'Snapshot', 'VaultStandard', or "
+                    "'SnapshotAndVaultStandard'."
+                )
+                rp_tier = None
+
+            # Filter by matching tier
+            if rp_tier == tier:
+                filtered_recovery_points.append(rp)
+
+        return filtered_recovery_points
+
     return paged_recovery_points
 
 
 def update_policy_for_item(cmd, client, resource_group_name, vault_name, item, policy, tenant_id=None,
-                           is_critical_operation=False):
+                           is_critical_operation=False, yes=False):
     if item.properties.backup_management_type != policy.properties.backup_management_type:
         raise CLIError(
             """
@@ -284,6 +351,13 @@ def update_policy_for_item(cmd, client, resource_group_name, vault_name, item, p
                                                  aux_tenants=[tenant_id]).protected_items
             afs_item.properties.resource_guard_operation_requests = [helper.get_resource_guard_operation_request(
                 cmd.cli_ctx, resource_group_name, vault_name, "updateProtection")]
+
+    # Validate existing & new policy
+    existing_policy_name = item.properties.policy_id.split('/')[-1]
+    existing_policy = common.show_policy(protection_policies_cf(cmd.cli_ctx), resource_group_name, vault_name,
+                                         existing_policy_name)
+    helper.validate_update_policy_request(existing_policy, policy, yes)
+
     # Update policy
     result = client.create_or_update(vault_name, resource_group_name, fabric_name,
                                      container_uri, item_uri, afs_item, cls=helper.get_pipeline_response)
@@ -291,7 +365,7 @@ def update_policy_for_item(cmd, client, resource_group_name, vault_name, item, p
 
 
 def disable_protection(cmd, client, resource_group_name, vault_name, item,
-                       retain_recovery_points_as_per_policy=False):
+                       retain_recovery_points_as_per_policy=False, tenant_id=None):
     # Get container and item URIs
     container_uri = helper.get_protection_container_uri_from_id(item.id)
     item_uri = helper.get_protected_item_uri_from_id(item.id)
@@ -304,6 +378,19 @@ def disable_protection(cmd, client, resource_group_name, vault_name, item,
         afs_item_properties.protection_state = ProtectionState.protection_stopped
     afs_item_properties.source_resource_id = item.properties.source_resource_id
     afs_item = ProtectedItemResource(properties=afs_item_properties)
+
+    # ResourceGuard scenario: if we are stopping backup and there is MUA setup for the scenario,
+    # we want to set the appropriate parameters.
+    if afs_item.properties.protection_state == ProtectionState.protection_stopped:
+        if helper.has_resource_guard_mapping(cmd.cli_ctx, resource_group_name,
+                                             vault_name, "RecoveryServicesStopProtection"):
+            # Cross Tenant scenario
+            if tenant_id is not None:
+                client = get_mgmt_service_client(cmd.cli_ctx, RecoveryServicesBackupClient,
+                                                 aux_tenants=[tenant_id]).protected_item
+            afs_item.properties.resource_guard_operation_requests = [helper.get_resource_guard_operation_request(
+                cmd.cli_ctx, resource_group_name, vault_name, "RecoveryServicesStopProtection")]
+
     result = client.create_or_update(vault_name, resource_group_name, fabric_name,
                                      container_uri, item_uri, afs_item, cls=helper.get_pipeline_response)
     return helper.track_backup_job(cmd.cli_ctx, result, vault_name, resource_group_name)
@@ -334,7 +421,7 @@ def _get_storage_account_id(cli_ctx, storage_account_name, storage_account_rg):
 
 
 def set_policy(cmd, client, resource_group_name, vault_name, policy, policy_name, tenant_id=None,
-               is_critical_operation=False):
+               is_critical_operation=False, yes=False):
     if policy_name is None:
         raise CLIError(
             """
@@ -344,7 +431,8 @@ def set_policy(cmd, client, resource_group_name, vault_name, policy, policy_name
     policy_object = helper.get_policy_from_json(client, policy)
     policy_object.properties.work_load_type = workload_type
     existing_policy = common.show_policy(client, resource_group_name, vault_name, policy_name)
-    helper.validate_update_policy_request(existing_policy, policy_object)
+
+    helper.validate_update_policy_request(existing_policy, policy_object, yes)
     if is_critical_operation:
         if helper.is_retention_duration_decreased(existing_policy, policy_object, "AzureStorage"):
             # update the payload with critical operation and add auxiliary header for cross tenant case
