@@ -11,7 +11,7 @@ from azure.cli.testsdk import ScenarioTest, JMESPathCheckExists, ResourceGroupPr
     StorageAccountPreparer, record_only
 from azure.cli.testsdk.scenario_tests import AllowLargeResponse
 from .preparers import VaultPreparer, FileSharePreparer, AFSPolicyPreparer, AFSItemPreparer, \
-    AFSRPPreparer, FilePreparer
+    AFSRPPreparer, FilePreparer, RGPreparer
 
 subscription_id = "da364f0f-307b-41c9-9d47-b7413ec45535"
 unprotected_afs = "clitestafs"
@@ -26,7 +26,7 @@ vault_name = "sarath-vault"
 class BackupTests(ScenarioTest, unittest.TestCase):
     #@record_only()
     @AllowLargeResponse()
-    @ResourceGroupPreparer(location="eastus2euap", random_name_length=20)
+    @RGPreparer(location="eastus2euap", random_name_length=20)
     @VaultPreparer(soft_delete=False)
     @StorageAccountPreparer(location="eastus2euap")
     @FileSharePreparer()
@@ -55,12 +55,12 @@ class BackupTests(ScenarioTest, unittest.TestCase):
 
         # Disable Protection
         self.cmd('backup protection disable -g {rg} -v {vault} -c {container} -i {item} --backup-management-type AzureStorage --delete-backup-data true --yes')
-        self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
-        time.sleep(100)
+        # self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
+        # time.sleep(100)
 
     #@record_only()
     @AllowLargeResponse()
-    @ResourceGroupPreparer(location="eastus2euap", random_name_length=20)
+    @RGPreparer(location="eastus2euap", random_name_length=20)
     @VaultPreparer(soft_delete=False)
     @StorageAccountPreparer(location="eastus2euap")
     @FileSharePreparer()
@@ -103,13 +103,13 @@ class BackupTests(ScenarioTest, unittest.TestCase):
 
         self.cmd('backup protection disable -g {rg} -v {vault} -c {sa1} -i {item1} --backup-management-type AzureStorage --delete-backup-data true --yes').get_output_in_json()
         self.cmd('backup protection disable -g {rg} -v {vault} -c {sa2} -i {item2} --backup-management-type AzureStorage --delete-backup-data true --yes').get_output_in_json()
-        self.cmd('backup container unregister -g {rg} -v {vault} -c {sa1} --yes --backup-management-type AzureStorage')
-        self.cmd('backup container unregister -g {rg} -v {vault} -c {sa2} --yes --backup-management-type AzureStorage')
-        time.sleep(100)
+        # self.cmd('backup container unregister -g {rg} -v {vault} -c {sa1} --yes --backup-management-type AzureStorage')
+        # self.cmd('backup container unregister -g {rg} -v {vault} -c {sa2} --yes --backup-management-type AzureStorage')
+        # time.sleep(100)
 
     #@record_only()
     @AllowLargeResponse()
-    @ResourceGroupPreparer(location="eastus2euap", random_name_length=20)
+    @RGPreparer(location="eastus2euap", random_name_length=20)
     @VaultPreparer(soft_delete=False)
     @StorageAccountPreparer(location="eastus2euap")
     @FileSharePreparer()
@@ -173,12 +173,12 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         self.assertIn(self.kwargs['newpolicy'].lower(), item1_json['properties']['policyId'].split('/')[-1].lower())
         self.cmd('backup protection disable -g {rg} -v {vault} -c {container} -i {item1} --backup-management-type AzureStorage --delete-backup-data true --yes').get_output_in_json()
         self.cmd('backup protection disable -g {rg} -v {vault} -c {container} -i {item2} --backup-management-type AzureStorage --delete-backup-data true --yes').get_output_in_json()
-        self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
-        time.sleep(100)
+        # self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
+        # time.sleep(100)
 
     #@record_only()
     @AllowLargeResponse()
-    @ResourceGroupPreparer(location="eastus2euap", random_name_length=20)
+    @RGPreparer(location="eastus2euap", random_name_length=20)
     @VaultPreparer(soft_delete=False)
     @StorageAccountPreparer(location="eastus2euap")
     @FileSharePreparer()
@@ -215,13 +215,13 @@ class BackupTests(ScenarioTest, unittest.TestCase):
 
         self.assertTrue(rp_count1 + 1 == rp_count2)
         self.cmd('backup protection disable -g {rg} -v {vault} -c {container} -i {item1} --backup-management-type AzureStorage --delete-backup-data true --yes').get_output_in_json()
-        self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
-        time.sleep(100)
+        # self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
+        # time.sleep(100)
 
     #@record_only()
     @AllowLargeResponse()
-    @ResourceGroupPreparer(location="eastus2euap", random_name_length=20)
-    @ResourceGroupPreparer(location="centraluseuap", random_name_length=30, parameter_name="resource_group2")
+    @RGPreparer(location="eastus2euap", random_name_length=20)
+    @RGPreparer(location="centraluseuap", random_name_length=30, parameter_name="resource_group2")
     @VaultPreparer(soft_delete=False)
     @StorageAccountPreparer(location="centraluseuap", parameter_name="storage_account", resource_group_parameter_name="resource_group")
     @StorageAccountPreparer(location="centraluseuap", parameter_name="storage_account_rg2", resource_group_parameter_name="resource_group2")
@@ -355,12 +355,12 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         ])
 
         self.cmd('backup protection disable -g {rg} -v {vault} -c {container} -i {item1} --backup-management-type AzureStorage --delete-backup-data true --yes').get_output_in_json()
-        self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
-        time.sleep(100)
+        # self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
+        # time.sleep(100)
 
     #@record_only()
     @AllowLargeResponse()
-    @ResourceGroupPreparer(location="eastus2euap", random_name_length=20)
+    @RGPreparer(location="eastus2euap", random_name_length=20)
     @VaultPreparer(soft_delete=False)
     @StorageAccountPreparer(location="eastus2euap")
     @FileSharePreparer()
@@ -408,13 +408,13 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         item_json = self.cmd('backup item list -g {rg} -v {vault} -c {container} --backup-management-type {type}').get_output_in_json()
         protected_item_count2 = len(item_json)
 
-        self.assertTrue(protected_item_count1 == protected_item_count2 + 1)
-        self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
-        time.sleep(100)
+        self.assertTrue(protected_item_count1 == protected_item_count2)
+        # self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
+        # time.sleep(100)
 
     #@record_only()
     @AllowLargeResponse()
-    @ResourceGroupPreparer(location="eastus2euap", random_name_length=20)
+    @RGPreparer(location="eastus2euap", random_name_length=20)
     @VaultPreparer(soft_delete=False)
     @StorageAccountPreparer(location="eastus2euap")
     @FileSharePreparer()
@@ -467,12 +467,12 @@ class BackupTests(ScenarioTest, unittest.TestCase):
 
         self.kwargs['afsitem'] = self.cmd('backup item list -g {rg} -v {vault} -c {container} --backup-management-type AzureStorage --query [0].name').get_output_in_json()
         self.cmd('backup protection disable -g {rg} -v {vault} -c {container} -i {afsitem} --backup-management-type AzureStorage --delete-backup-data true --yes').get_output_in_json()
-        self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
-        time.sleep(100)
+        # self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
+        # time.sleep(100)
 
     #@record_only()
     @AllowLargeResponse()
-    @ResourceGroupPreparer(location="eastus2euap", random_name_length=20)
+    @RGPreparer(location="eastus2euap", random_name_length=20)
     @VaultPreparer(soft_delete=False)
     @StorageAccountPreparer(location="eastus2euap")
     @FileSharePreparer()
@@ -501,14 +501,14 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         self.kwargs['item'] = self.cmd('backup item list -g {rg} -v {vault} -c {container} --query [0].name').get_output_in_json()
         self.cmd('backup protection disable -g {rg} -v {vault} -c {container_name} -i {item} --backup-management-type AzureStorage --delete-backup-data true --yes')
 
-        self.cmd('backup container unregister -g {rg} -v {vault} -c {container_name} --yes')
+        # self.cmd('backup container unregister -g {rg} -v {vault} -c {container_name} --yes')
 
-        self.cmd('backup container list -v {vault} -g {rg} --backup-management-type {type}', checks=[
-            self.check("length([?properties.friendlyName == '{container}'])", 0)])
-        time.sleep(100)
+        # self.cmd('backup container list -v {vault} -g {rg} --backup-management-type {type}', checks=[
+        #     self.check("length([?properties.friendlyName == '{container}'])", 0)])
+        # time.sleep(100)
 
     @AllowLargeResponse()
-    @ResourceGroupPreparer(location="eastus2euap", random_name_length=20)
+    @RGPreparer(location="eastus2euap", random_name_length=20)
     @VaultPreparer(soft_delete=False)
     @StorageAccountPreparer(location="eastus2euap")
     @FileSharePreparer()
@@ -573,11 +573,11 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         self.cmd("backup policy set -g {rg} -v {vault} --policy '{default_snapshot_policy_json}' -n {default_vault_policy} --yes", expect_failure=True)
         self.kwargs['afsitem'] = self.cmd('backup item list -g {rg} -v {vault} -c {container} --backup-management-type AzureStorage --query [0].name').get_output_in_json()
         self.cmd('backup protection disable -g {rg} -v {vault} -c {container} -i {afsitem} --backup-management-type AzureStorage --delete-backup-data true --yes').get_output_in_json()
-        self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
-        time.sleep(100)
+        # self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
+        # time.sleep(100)
 
     @AllowLargeResponse()
-    @ResourceGroupPreparer(location="eastus2euap", random_name_length=20)
+    @RGPreparer(location="eastus2euap", random_name_length=20)
     @VaultPreparer(soft_delete=False)
     @StorageAccountPreparer(location="eastus2euap")
     @FileSharePreparer()
@@ -645,5 +645,5 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         self.assertIn(self.kwargs['newpolicy'].lower(), item1_json['properties']['policyId'].split('/')[-1].lower())
         self.cmd('backup protection disable -g {rg} -v {vault} -c {container} -i {item1} --backup-management-type AzureStorage --delete-backup-data true --yes').get_output_in_json()
         self.cmd('backup protection disable -g {rg} -v {vault} -c {container} -i {item2} --backup-management-type AzureStorage --delete-backup-data true --yes').get_output_in_json()
-        self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
-        time.sleep(100)
\ No newline at end of file
+        # self.cmd('backup container unregister -g {rg} -v {vault} -c {container} --yes --backup-management-type AzureStorage')
+        # time.sleep(100)
\ No newline at end of file
