@@ -8,6 +8,63 @@ from .afdx_scenario_mixin import CdnAfdScenarioMixin
 
 
 class CdnAfdOriginGroupScenarioTest(CdnAfdScenarioMixin, ScenarioTest):
+    @ResourceGroupPreparer(additional_tags={'owner': 'jingnanxu'})
+    def test_afd_origin_group_disable_probe(self, resource_group):
+        profile_name = self.create_random_name(prefix='profile', length=16)
+        self.afd_profile_create_cmd(resource_group, profile_name)
+
+        list_checks = [JMESPathCheck('length(@)', 0)]
+        self.afd_origin_group_list_cmd(resource_group, profile_name, list_checks)
+
+        origin_group_name = self.create_random_name(prefix='og', length=16)
+        checks = [JMESPathCheck('name', origin_group_name),
+                  JMESPathCheck('loadBalancingSettings.sampleSize', 4),
+                  JMESPathCheck('loadBalancingSettings.successfulSamplesRequired', 3),
+                  JMESPathCheck('loadBalancingSettings.additionalLatencyInMilliseconds', 50),
+                  JMESPathCheck('healthProbeSettings.probePath', "/test1/azure.txt"),
+                  JMESPathCheck('healthProbeSettings.probeProtocol', "Http"),
+                  JMESPathCheck('healthProbeSettings.probeIntervalInSeconds', 120),
+                  JMESPathCheck('healthProbeSettings.probeRequestType', "GET"),
+                  JMESPathCheck('provisioningState', 'Succeeded')]
+        self.afd_origin_group_create_cmd(resource_group,
+                                         profile_name,
+                                         origin_group_name,
+                                         "--probe-request-type GET --probe-protocol Http --probe-interval-in-seconds 120 --probe-path /test1/azure.txt " +
+                                         "--sample-size 4 --successful-samples-required 3 --additional-latency-in-milliseconds 50 --enable-health-probe true",
+                                         checks=checks)
+
+        update_checks = [JMESPathCheck('name', origin_group_name),
+                         JMESPathCheck('loadBalancingSettings.sampleSize', 4),
+                         JMESPathCheck('loadBalancingSettings.successfulSamplesRequired', 3),
+                         JMESPathCheck('loadBalancingSettings.additionalLatencyInMilliseconds', 50),
+                         JMESPathCheck('healthProbeSettings.probePath', "/test1/azure.txt"),
+                         JMESPathCheck('healthProbeSettings.probeProtocol', "Https"),
+                         JMESPathCheck('healthProbeSettings.probeIntervalInSeconds', 120),
+                         JMESPathCheck('healthProbeSettings.probeRequestType', "GET"),
+                         JMESPathCheck('provisioningState', 'Succeeded')]
+        options = '--probe-request-type GET --probe-protocol Https'
+        self.afd_origin_group_update_cmd(resource_group,
+                                         profile_name,
+                                         origin_group_name,
+                                         options=options,
+                                         checks=update_checks)
+
+        update_checks = [JMESPathCheck('name', origin_group_name),
+                         JMESPathCheck('loadBalancingSettings.sampleSize', 4),
+                         JMESPathCheck('loadBalancingSettings.successfulSamplesRequired', 3),
+                         JMESPathCheck('loadBalancingSettings.additionalLatencyInMilliseconds', 50),
+                         JMESPathCheck('healthProbeSettings.probePath', None),
+                         JMESPathCheck('healthProbeSettings.probeProtocol', None),
+                         JMESPathCheck('healthProbeSettings.probeIntervalInSeconds', None),
+                         JMESPathCheck('healthProbeSettings.probeRequestType', None),
+                         JMESPathCheck('provisioningState', 'Succeeded')]
+        options = '--enable-health-probe false'
+        self.afd_origin_group_update_cmd(resource_group,
+                                         profile_name,
+                                         origin_group_name,
+                                         options=options,
+                                         checks=update_checks)
+
     @ResourceGroupPreparer(additional_tags={'owner': 'jingnanxu'})
     def test_afd_origin_group_crud(self, resource_group):
         profile_name = self.create_random_name(prefix='profile', length=16)
