@@ -34,13 +34,12 @@ def show_cloud(cmd, cloud_name=None):
         raise CLIError(e)
 
 
-def _populate_from_metadata_endpoint(cloud, arm_endpoint, session=None):
-    endpoints_in_metadata = ['active_directory_graph_resource_id',
-                             'active_directory_resource_id', 'active_directory']
-    METADATA_ENDPOINT_SUFFIX = '/metadata/endpoints?api-version=2015-01-01'
-    if not arm_endpoint or all([cloud.endpoints.has_endpoint_set(n) for n in endpoints_in_metadata]):  # pylint: disable=use-a-generator
-        return
+def _populate_from_metadata_endpoint(arm_endpoint, session=None):
+    METADATA_ENDPOINT_SUFFIX = '/metadata/endpoints?api-version=2022-09-01'
+    if not arm_endpoint:  # pylint: disable=use-a-generator
+        return Cloud('')
     import requests
+    from azure.cli.core.cloud import _arm_to_cli_mapper
     error_msg_fmt = "Unable to get endpoints from the cloud.\n{}"
     try:
         session = requests.Session() if session is None else session
@@ -48,17 +47,9 @@ def _populate_from_metadata_endpoint(cloud, arm_endpoint, session=None):
         response = session.get(metadata_endpoint)
         if response.status_code == 200:
             metadata = response.json()
-            if not cloud.endpoints.has_endpoint_set('gallery'):
-                setattr(cloud.endpoints, 'gallery', metadata.get('galleryEndpoint'))
-            if not cloud.endpoints.has_endpoint_set('active_directory_graph_resource_id'):
-                setattr(cloud.endpoints, 'active_directory_graph_resource_id', metadata.get('graphEndpoint'))
-            if not cloud.endpoints.has_endpoint_set('active_directory'):
-                setattr(cloud.endpoints, 'active_directory', metadata['authentication'].get('loginEndpoint'))
-            if not cloud.endpoints.has_endpoint_set('active_directory_resource_id'):
-                setattr(cloud.endpoints, 'active_directory_resource_id', metadata['authentication']['audiences'][0])
-        else:
-            msg = 'Server returned status code {} for {}'.format(response.status_code, metadata_endpoint)
-            raise CLIError(error_msg_fmt.format(msg))
+            return _arm_to_cli_mapper(metadata)
+        msg = 'Server returned status code {} for {}'.format(response.status_code, metadata_endpoint)
+        raise CLIError(error_msg_fmt.format(msg))
     except (requests.exceptions.ConnectionError, requests.exceptions.HTTPError) as err:
         msg = 'Please ensure you have network connection. Error detail: {}'.format(str(err))
         raise CLIError(error_msg_fmt.format(msg))
@@ -67,12 +58,18 @@ def _populate_from_metadata_endpoint(cloud, arm_endpoint, session=None):
         raise CLIError(error_msg_fmt.format(msg))
 
 
-def _build_cloud(cli_ctx, cloud_name, cloud_config=None, is_update=False, cloud_args=None):
-    from azure.cli.core.cloud import CloudEndpointNotSetException
+def _build_cloud(cli_ctx, cloud_name, cloud_config=None, cloud_args=None):
     if cloud_config:
         # Using JSON format so convert the keys to snake case
         cloud_args = {to_snake_case(k): v for k, v in cloud_config.items()}
-    c = Cloud(cloud_name)
+    arm_endpoint = None
+    if 'endpoints' in cloud_args:
+        arm_endpoint = (cloud_args['endpoints'].get('resource_manager', None) or
+                        cloud_args['endpoints'].get('resourceManager', None))
+    if 'endpoint_resource_manager' in cloud_args:
+        arm_endpoint = cloud_args['endpoint_resource_manager']
+    c = _populate_from_metadata_endpoint(arm_endpoint)
+    c.name = cloud_name
     c.profile = cloud_args.get('profile', None)
     try:
         endpoints = cloud_args['endpoints']
@@ -93,18 +90,6 @@ def _build_cloud(cli_ctx, cloud_name, cloud_config=None, is_update=False, cloud_
         elif arg.startswith('suffix_') and cloud_args[arg] is not None:
             setattr(c.suffixes, arg.replace('suffix_', ''), cloud_args[arg])
 
-    try:
-        arm_endpoint = c.endpoints.resource_manager
-    except CloudEndpointNotSetException:
-        arm_endpoint = None
-
-    from azure.cli.core.breaking_change import print_conditional_breaking_change
-    if arm_endpoint and is_update:
-        print_conditional_breaking_change(cli_ctx, tag='CloudUpdateOutputBreakingChange')
-    elif arm_endpoint:
-        print_conditional_breaking_change(cli_ctx, tag='CloudRegisterOutputBreakingChange')
-
-    _populate_from_metadata_endpoint(c, arm_endpoint)
     required_endpoints = {'resource_manager': '--endpoint-resource-manager',
                           'active_directory': '--endpoint-active-directory',
                           'active_directory_resource_id': '--endpoint-active-directory-resource-id',
@@ -138,7 +123,7 @@ def register_cloud(cmd,
                    suffix_azure_datalake_store_file_system_endpoint=None,
                    suffix_azure_datalake_analytics_catalog_and_job_endpoint=None,
                    suffix_acr_login_server_endpoint=None):
-    c = _build_cloud(cmd.cli_ctx, cloud_name, cloud_config=cloud_config, is_update=False,
+    c = _build_cloud(cmd.cli_ctx, cloud_name, cloud_config=cloud_config,
                      cloud_args=locals())
     try:
         add_cloud(cmd.cli_ctx, c)
@@ -167,7 +152,7 @@ def modify_cloud(cmd,
                  suffix_acr_login_server_endpoint=None):
     if not cloud_name:
         cloud_name = cmd.cli_ctx.cloud.name
-    c = _build_cloud(cmd.cli_ctx, cloud_name, cloud_config=cloud_config, is_update=True,
+    c = _build_cloud(cmd.cli_ctx, cloud_name, cloud_config=cloud_config,
                      cloud_args=locals())
     try:
         update_cloud(cmd.cli_ctx, c)
