@@ -10,23 +10,25 @@ from azure.cli.command_modules.iot._client_factory import (iot_hub_service_facto
 from azure.cli.command_modules.iot._utils import _dps_certificate_response_transform
 
 CS_DEPRECATION_INFO = 'IoT Extension (azure-iot) connection-string command (az iot hub connection-string show)'
+ROUTE_DEPRECATION_INFO = 'IoT Extension (azure-iot) message-route command group (az iot hub message-route)'
+ENDPOINT_DEPRECATION_INFO = 'IoT Extension (azure-iot) message-endpoint command group (az iot hub message-endpoint)'
 
 
 class PolicyUpdateResultTransform(LongRunningOperation):  # pylint: disable=too-few-public-methods
     def __call__(self, poller):
-        result = super(PolicyUpdateResultTransform, self).__call__(poller)
+        result = super().__call__(poller)
         return result.properties.authorization_policies
 
 
 class EndpointUpdateResultTransform(LongRunningOperation):  # pylint: disable=too-few-public-methods
     def __call__(self, poller):
-        result = super(EndpointUpdateResultTransform, self).__call__(poller)
+        result = super().__call__(poller)
         return result.properties.routing.endpoints
 
 
 class RouteUpdateResultTransform(LongRunningOperation):  # pylint: disable=too-few-public-methods
     def __call__(self, poller):
-        result = super(RouteUpdateResultTransform, self).__call__(poller)
+        result = super().__call__(poller)
         return result.properties.routing.routes
 
 
@@ -40,7 +42,7 @@ class HubDeleteResultTransform(LongRunningOperation):  # pylint: disable=too-few
         if not poller:
             return poller
         try:
-            super(HubDeleteResultTransform, self).__call__(poller)
+            super().__call__(poller)
         except CLIError as e:
             if 'not found' not in str(e):
                 raise e
@@ -128,7 +130,7 @@ def load_command_table(self, _):  # pylint: disable=too-many-statements
         g.custom_command('create', 'iot_hub_create', supports_no_wait=True)
         g.custom_command('list', 'iot_hub_list')
         g.custom_command('show-connection-string', 'iot_hub_show_connection_string',
-                         deprecate_info=self.deprecate(redirect=CS_DEPRECATION_INFO))
+                         deprecate_info=self.deprecate(redirect=CS_DEPRECATION_INFO, hide=True))
         g.custom_show_command('show', 'iot_hub_get')
         g.generic_update_command('update', getter_name='iot_hub_get', setter_name='iot_hub_update',
                                  command_type=update_custom_util, custom_func_name='update_iot_hub_custom')
@@ -162,7 +164,8 @@ def load_command_table(self, _):  # pylint: disable=too-many-statements
         g.custom_command('renew-key', 'iot_hub_policy_key_renew', supports_no_wait=True)
 
     # iot hub routing endpoint commands
-    with self.command_group('iot hub routing-endpoint', client_factory=iot_hub_service_factory) as g:
+    with self.command_group('iot hub routing-endpoint', client_factory=iot_hub_service_factory,
+                            deprecate_info=self.deprecate(redirect=ENDPOINT_DEPRECATION_INFO, hide=True)) as g:
         g.custom_command('create', 'iot_hub_routing_endpoint_create',
                          transform=EndpointUpdateResultTransform(self.cli_ctx))
         g.custom_show_command('show', 'iot_hub_routing_endpoint_show')
@@ -179,7 +182,8 @@ def load_command_table(self, _):  # pylint: disable=too-many-statements
         g.custom_command('update', 'iot_message_enrichment_update')
 
     # iot hub route commands
-    with self.command_group('iot hub route', client_factory=iot_hub_service_factory) as g:
+    with self.command_group('iot hub route', client_factory=iot_hub_service_factory,
+                            deprecate_info=self.deprecate(redirect=ROUTE_DEPRECATION_INFO, hide=True)) as g:
         g.custom_command('create', 'iot_hub_route_create', transform=RouteUpdateResultTransform(self.cli_ctx))
         g.custom_show_command('show', 'iot_hub_route_show')
         g.custom_command('list', 'iot_hub_route_list')
