@@ -9,10 +9,10 @@ from azure.cli.core.commands import CliCommandType
 from azure.cli.core.profiles import get_api_version, ResourceType
 
 from azure.cli.command_modules.keyvault._client_factory import (
-    get_client, get_client_factory, Clients, is_azure_stack_profile)
+    get_client, get_client_factory, Clients)
 
 from azure.cli.command_modules.keyvault._transformers import (
-    filter_out_managed_resources, transform_security_domain_output,
+    filter_out_managed_resources,
     multi_transformers, transform_key_decryption_output, keep_max_results, transform_key_list_output,
     transform_key_output, transform_key_encryption_output, transform_key_random_output,
     transform_secret_list, transform_deleted_secret_list, transform_secret_set,
@@ -50,28 +50,21 @@ def load_command_table(self, _):
     data_certificate_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_CERTIFICATES)
     data_secret_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_SECRETS)
 
-    if not is_azure_stack_profile(self):
-        mgmt_hsms_entity = get_client(self.cli_ctx, ResourceType.MGMT_KEYVAULT, Clients.managed_hsms)
-        mgmt_hsms_regions_entity = get_client(self.cli_ctx, ResourceType.MGMT_KEYVAULT, Clients.mhsm_regions)
-        data_security_domain_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_SECURITY_DOMAIN)
-        data_backup_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_ADMINISTRATION_BACKUP)
-        data_access_control_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_ADMINISTRATION_ACCESS_CONTROL)
-        data_setting_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_ADMINISTRATION_SETTING)
-    else:
-        mgmt_hsms_entity = mgmt_hsms_regions_entity = data_security_domain_entity = data_backup_entity = \
-            data_access_control_entity = data_setting_entity = None
+    mgmt_hsms_entity = get_client(self.cli_ctx, ResourceType.MGMT_KEYVAULT, Clients.managed_hsms)
+    mgmt_hsms_regions_entity = get_client(self.cli_ctx, ResourceType.MGMT_KEYVAULT, Clients.mhsm_regions)
+    data_security_domain_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_SECURITY_DOMAIN)
+    data_backup_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_ADMINISTRATION_BACKUP)
+    data_access_control_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_ADMINISTRATION_ACCESS_CONTROL)
+    data_setting_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_ADMINISTRATION_SETTING)
 
     kv_vaults_custom = CliCommandType(
         operations_tmpl='azure.cli.command_modules.keyvault.custom#{}',
         client_factory=get_client_factory(ResourceType.MGMT_KEYVAULT, Clients.vaults)
     )
-    if not is_azure_stack_profile(self):
-        kv_hsms_custom = CliCommandType(
-            operations_tmpl='azure.cli.command_modules.keyvault.custom#{}',
-            client_factory=get_client_factory(ResourceType.MGMT_KEYVAULT, Clients.managed_hsms)
-        )
-    else:
-        kv_hsms_custom = None
+    kv_hsms_custom = CliCommandType(
+        operations_tmpl='azure.cli.command_modules.keyvault.custom#{}',
+        client_factory=get_client_factory(ResourceType.MGMT_KEYVAULT, Clients.managed_hsms)
+    )
     # endregion
 
     # Management Plane Commands
@@ -93,14 +86,13 @@ def load_command_table(self, _):
             supports_no_wait=True)
         g.wait_command('wait')
 
-    if not is_azure_stack_profile(self):
-        with self.command_group('keyvault', mgmt_hsms_entity.command_type,
-                                client_factory=mgmt_hsms_entity.client_factory) as g:
-            g.generic_update_command(
-                'update-hsm', setter_name='update_hsm_setter', setter_type=kv_hsms_custom,
-                custom_func_name='update_hsm', supports_no_wait=True)
-            g.custom_wait_command('wait-hsm', 'wait_hsm')
-            g.custom_command('check-name', 'check_name_availability')
+    with self.command_group('keyvault', mgmt_hsms_entity.command_type,
+                            client_factory=mgmt_hsms_entity.client_factory) as g:
+        g.generic_update_command(
+            'update-hsm', setter_name='update_hsm_setter', setter_type=kv_hsms_custom,
+            custom_func_name='update_hsm', supports_no_wait=True)
+        g.custom_wait_command('wait-hsm', 'wait_hsm')
+        g.custom_command('check-name', 'check_name_availability')
 
     with self.command_group('keyvault network-rule',
                             mgmt_vaults_entity.command_type,
@@ -135,26 +127,24 @@ def load_command_table(self, _):
         g.custom_command('list', 'list_private_link_resource', transform=gen_dict_to_list_transform(key='value'))
 
     # Data Plane Commands
-    if not is_azure_stack_profile(self):
-        with self.command_group('keyvault backup', data_backup_entity.command_type) as g:
-            g.keyvault_custom('start', 'full_backup')
+    with self.command_group('keyvault backup', data_backup_entity.command_type) as g:
+        g.keyvault_custom('start', 'full_backup')
 
-        with self.command_group('keyvault restore', data_backup_entity.command_type) as g:
-            g.keyvault_custom('start', 'full_restore')
+    with self.command_group('keyvault restore', data_backup_entity.command_type) as g:
+        g.keyvault_custom('start', 'full_restore')
 
-        with self.command_group('keyvault security-domain', data_security_domain_entity.command_type) as g:
-            g.keyvault_custom('init-recovery', 'security_domain_init_recovery')
-            g.keyvault_custom('restore-blob', 'security_domain_restore_blob')
-            g.keyvault_custom('upload', 'security_domain_upload', supports_no_wait=True,
-                              transform=transform_security_domain_output)
-            g.keyvault_custom('download', 'security_domain_download', supports_no_wait=True,
-                              transform=transform_security_domain_output)
-            g.keyvault_custom('wait', '_wait_security_domain_operation', transform=transform_security_domain_output)
+    with self.command_group('keyvault security-domain', data_security_domain_entity.command_type) as g:
+        g.keyvault_custom('init-recovery', 'security_domain_init_recovery')
+        g.keyvault_custom('restore-blob', 'security_domain_restore_blob')
+        g.keyvault_custom('upload', 'security_domain_upload', supports_no_wait=True)
+        g.keyvault_custom('download', 'security_domain_download', supports_no_wait=True)
+        g.keyvault_custom('wait', '_wait_security_domain_operation')
 
     with self.command_group('keyvault key', data_key_entity.command_type) as g:
         g.keyvault_custom('create', 'create_key', transform=transform_key_output, validator=validate_key_create)
         g.keyvault_command('set-attributes', 'update_key_properties', transform=transform_key_output)
         g.keyvault_command('show', 'get_key', transform=transform_key_output)
+        g.keyvault_custom('get-attestation', 'get_key_attestation')
         g.keyvault_custom('import', 'import_key', transform=transform_key_output)
         g.keyvault_custom('get-policy-template', 'get_policy_template', is_preview=True)
         g.keyvault_custom('encrypt', 'encrypt_key', is_preview=True, transform=transform_key_encryption_output)
@@ -173,16 +163,15 @@ def load_command_table(self, _):
         g.keyvault_custom('backup', 'backup_key')
         g.keyvault_custom('restore', 'restore_key', supports_no_wait=True, transform=transform_key_output)
 
-    if not is_azure_stack_profile(self):
-        with self.command_group('keyvault key', data_key_entity.command_type) as g:
-            g.keyvault_command('random', 'get_random_bytes', transform=transform_key_random_output)
-            g.keyvault_command('rotate', 'rotate_key', transform=transform_key_output)
-            g.keyvault_custom('sign', 'sign_key')
-            g.keyvault_custom('verify', 'verify_key')
+    with self.command_group('keyvault key', data_key_entity.command_type) as g:
+        g.keyvault_command('random', 'get_random_bytes', transform=transform_key_random_output)
+        g.keyvault_command('rotate', 'rotate_key', transform=transform_key_output)
+        g.keyvault_custom('sign', 'sign_key')
+        g.keyvault_custom('verify', 'verify_key')
 
-        with self.command_group('keyvault key rotation-policy', data_key_entity.command_type) as g:
-            g.keyvault_command('show', 'get_key_rotation_policy', )
-            g.keyvault_custom('update', 'update_key_rotation_policy')
+    with self.command_group('keyvault key rotation-policy', data_key_entity.command_type) as g:
+        g.keyvault_command('show', 'get_key_rotation_policy', )
+        g.keyvault_custom('update', 'update_key_rotation_policy')
 
     # secret track2
     with self.command_group('keyvault secret', data_secret_entity.command_type) as g:
@@ -212,7 +201,7 @@ def load_command_table(self, _):
                                'will be moved to the soft deleted state. You will not be able to create a secret '
                                'with the same name within this key vault until the secret has been purged from the '
                                'soft-deleted state. Please see the following documentation for additional guidance.'
-                               '\nhttps://docs.microsoft.com/azure/key-vault/general/soft-delete-overview'))
+                               '\nhttps://learn.microsoft.com/azure/key-vault/general/soft-delete-overview'))
         g.keyvault_command('purge', 'purge_deleted_secret')
         g.keyvault_command('recover', 'begin_recover_deleted_secret', transform=transform_secret_recover)
         g.keyvault_custom('download', 'download_secret')
@@ -243,7 +232,7 @@ def load_command_table(self, _):
                                    'create a certificate with the same name within this key vault until the '
                                    'certificate has been purged from the soft-deleted state. Please see the following '
                                    'documentation for additional guidance.\n'
-                                   'https://docs.microsoft.com/azure/key-vault/general/soft-delete-overview'),
+                                   'https://learn.microsoft.com/azure/key-vault/general/soft-delete-overview'),
                            transform=transform_certificate_delete)
         g.keyvault_command('purge', 'purge_deleted_certificate')
         g.keyvault_command('recover', 'begin_recover_deleted_certificate', transform=transform_certificate_recover)
@@ -288,35 +277,32 @@ def load_command_table(self, _):
                                transform_certificate_issuer_admin_list))
         g.keyvault_custom('delete', 'delete_certificate_issuer_admin')
 
-    if not is_azure_stack_profile(self):
-        with self.command_group('keyvault role', data_access_control_entity.command_type):
-            pass
+    with self.command_group('keyvault role', data_access_control_entity.command_type):
+        pass
 
-        with self.command_group('keyvault role assignment', data_access_control_entity.command_type) as g:
-            g.keyvault_custom('delete', 'delete_role_assignment', validator=validate_role_assignment_args)
-            g.keyvault_custom('list', 'list_role_assignments', table_transformer=transform_assignment_list)
-            g.keyvault_custom('create', 'create_role_assignment')
+    with self.command_group('keyvault role assignment', data_access_control_entity.command_type) as g:
+        g.keyvault_custom('delete', 'delete_role_assignment', validator=validate_role_assignment_args)
+        g.keyvault_custom('list', 'list_role_assignments', table_transformer=transform_assignment_list)
+        g.keyvault_custom('create', 'create_role_assignment')
 
-        with self.command_group('keyvault role definition', data_access_control_entity.command_type) as g:
-            g.keyvault_custom('list', 'list_role_definitions', table_transformer=transform_definition_list)
-            g.keyvault_custom('create', 'create_role_definition')
-            g.keyvault_custom('update', 'update_role_definition')
-            g.keyvault_custom('delete', 'delete_role_definition')
-            g.keyvault_custom('show', 'show_role_definition')
+    with self.command_group('keyvault role definition', data_access_control_entity.command_type) as g:
+        g.keyvault_custom('list', 'list_role_definitions', table_transformer=transform_definition_list)
+        g.keyvault_custom('create', 'create_role_definition')
+        g.keyvault_custom('update', 'update_role_definition')
+        g.keyvault_custom('delete', 'delete_role_definition')
+        g.keyvault_custom('show', 'show_role_definition')
 
-    if not is_azure_stack_profile(self):
-        with self.command_group('keyvault setting', data_setting_entity.command_type) as g:
-            g.keyvault_command('list', 'list_settings')
-            g.keyvault_command('show', 'get_setting')
-            g.keyvault_custom('update', 'update_hsm_setting')
+    with self.command_group('keyvault setting', data_setting_entity.command_type) as g:
+        g.keyvault_command('list', 'list_settings')
+        g.keyvault_command('show', 'get_setting')
+        g.keyvault_custom('update', 'update_hsm_setting')
 
-    if not is_azure_stack_profile(self):
-        with self.command_group('keyvault region', mgmt_hsms_regions_entity.command_type,
-                                client_factory=mgmt_hsms_regions_entity.client_factory, min_api='2023-02-01') as g:
-            g.command('list', 'list_by_resource', client_factory=mgmt_hsms_regions_entity.client_factory)
+    with self.command_group('keyvault region', mgmt_hsms_regions_entity.command_type,
+                            client_factory=mgmt_hsms_regions_entity.client_factory, min_api='2023-02-01') as g:
+        g.command('list', 'list_by_resource', client_factory=mgmt_hsms_regions_entity.client_factory)
 
-        with self.command_group('keyvault region', mgmt_hsms_entity.command_type,
-                                client_factory=mgmt_hsms_entity.client_factory, min_api='2023-02-01') as g:
-            g.custom_command('add', 'add_hsm_region', supports_no_wait=True)
-            g.custom_command('remove', 'remove_hsm_region', supports_no_wait=True)
-            g.wait_command('wait')
+    with self.command_group('keyvault region', mgmt_hsms_entity.command_type,
+                            client_factory=mgmt_hsms_entity.client_factory, min_api='2023-02-01') as g:
+        g.custom_command('add', 'add_hsm_region', supports_no_wait=True)
+        g.custom_command('remove', 'remove_hsm_region', supports_no_wait=True)
+        g.wait_command('wait')
