@@ -8,9 +8,10 @@
 
 from knack.arguments import CLIArgumentType
 from azure.cli.core.commands.parameters import tags_type, get_location_type, get_enum_type, file_type, resource_group_name_type, get_three_state_flag
+from azure.cli.command_modules.mysql.action import AddArgs
 from azure.cli.command_modules.mysql.random.generate import generate_username
 from azure.cli.command_modules.mysql._validators import public_access_validator, maintenance_window_validator, ip_address_validator, \
-    firewall_rule_name_validator, validate_identity, validate_byok_identity, validate_identities
+    firewall_rule_name_validator, validate_identity, validate_byok_identity, validate_identities, validate_action_name, validate_branch
 from azure.cli.core.local_context import LocalContextAttribute, LocalContextAction
 from ._util import get_current_time
 from argcomplete.completers import FilesCompleter
@@ -62,6 +63,12 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             actions=[LocalContextAction.GET, LocalContextAction.SET],
             scopes=['mysql flexible-server']))
 
+    database_port_arg_type = CLIArgumentType(
+        type=int,
+        options_list=['--database-port'],
+        help='The port of the database. Default value is 3306'
+    )
+
     tier_arg_type = CLIArgumentType(
         options_list=['--tier'],
         help='Compute tier of the server. Accepted values: Burstable, GeneralPurpose, MemoryOptimized '
@@ -106,7 +113,37 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
     auto_scale_iops_arg_type = CLIArgumentType(
         arg_type=get_enum_type(['Enabled', 'Disabled']),
         options_list=['--auto-scale-iops'],
-        help='Enable or disable the auto scale iops. Default value is Disabled.'
+        help='Enable or disable the auto scale iops. Default value is Enabled.'
+    )
+
+    accelerated_logs_arg_type = CLIArgumentType(
+        arg_type=get_enum_type(['Enabled', 'Disabled']),
+        options_list=['--accelerated-logs'],
+        help='Enable or disable accelerated logs. Only support for Business Critical tier. Default value is Enabled.'
+    )
+
+    faster_restore_arg_type = CLIArgumentType(
+        arg_type=get_enum_type(['Enabled', 'Disabled']),
+        options_list=['--faster-restore'],
+        help='Enable or disable Auto scale IOPS configuration for both the source and the newly restored server to enable faster restore.'
+    )
+
+    faster_provisioning_arg_type = CLIArgumentType(
+        arg_type=get_enum_type(['Enabled', 'Disabled']),
+        options_list=['--faster-provisioning'],
+        help='Enable or disable Auto scale IOPS configuration for both the source and the newly provisioned replica server to enable faster provisioning.'
+    )
+
+    storage_redundancy_arg_type = CLIArgumentType(
+        arg_type=get_enum_type(['LocalRedundancy', 'ZoneRedundancy']),
+        options_list=['--storage-redundancy'],
+        help='Enable local redundancy or zone redundancy. Zone redundancy only supports Business Critical tier.'
+    )
+
+    maintenance_policy_patch_strategy_arg_type = CLIArgumentType(
+        arg_type=get_enum_type(['Regular', 'VirtualCanary']),
+        options_list=['--maintenance-policy-patch-strategy', '--patch-strategy'],
+        help='The patch strategy of maintenance policy. Accepted values: Regular, VirtualCanary. Default value is Regular.'
     )
 
     yes_arg_type = CLIArgumentType(
@@ -118,6 +155,8 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
     vnet_arg_type = CLIArgumentType(
         options_list=['--vnet'],
         help='Name or ID of a new or existing virtual network. '
+             'This parameter only applies if you are creating cross region replica server with private access. '
+             'For in-region read replica with private access, source server settings are carried over and this parameter is ignored. '
              'If you want to use a vnet from different resource group or subscription, '
              'please provide a resource ID. The name must be between 2 to 64 characters. '
              'The name must begin with a letter or number, end with a letter, number or underscore, '
@@ -133,6 +172,8 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
     subnet_arg_type = CLIArgumentType(
         options_list=['--subnet'],
         help='Name or resource ID of a new or existing subnet. '
+             'This parameter only applies if you are creating cross region replica server with private access. '
+             'For in-region read replica with private access, source server settings are carried over and this parameter is ignored. '
              'If you want to use a subnet from different resource group or subscription, please provide resource ID instead of name. '
              'Please note that the subnet will be delegated to flexibleServers. '
              'After delegation, this subnet cannot be used for any other type of Azure resources.'
@@ -182,7 +223,8 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
 
     private_dns_zone_arguments_arg_type = CLIArgumentType(
         options_list=['--private-dns-zone'],
-        help='This parameter only applies for a server with private access. '
+        help='This parameter only applies if you are creating cross region replica server with private access. '
+             'For in-region read replica with private access, source server settings are carried over and this parameter is ignored. '
              'The name or id of new or existing private dns zone. '
              'You can use the private dns zone from same resource group, different resource group, or different subscription. '
              'If you want to use a zone from different resource group or subscription, please provide resource Id. '
@@ -196,6 +238,13 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
              'The default value is set to current time.'
     )
 
+    maintenance_reschedule_time_arg_type = CLIArgumentType(
+        options_list=['--start-time'],
+        default=get_current_time(),
+        help='The maintenance reschedule start time in UTC(ISO8601 format), e.g., 2017-04-26T02:10:00+00:00'
+             'The default value is set to current time.'
+    )
+
     source_server_arg_type = CLIArgumentType(
         options_list=['--source-server'],
         help='The name or resource ID of the source server to restore from.'
@@ -219,6 +268,12 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         validator=validate_byok_identity
     )
 
+    backup_interval_arg_type = CLIArgumentType(
+        type=int,
+        options_list=['--backup-interval'],
+        help='The interval between backups in hours. Accepted values are 24, 12 and 6. The default value is 24.'
+    )
+
     key_arg_type = CLIArgumentType(
         options_list=['--key'],
         help='The resource ID of the primary keyvault key for data encryption.'
@@ -250,36 +305,62 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
 
     data_source_type_arg_type = CLIArgumentType(
         options_list=['--data-source-type'],
-        arg_type=get_enum_type(['mysql_single']),
+        arg_type=get_enum_type(['mysql_single', 'azure_blob']),
         help='Data source type. e.g., mysql_single: Azure Database for MySQL Servers. '
+             'azure_blob: Source backup provided in Azure blob container.'
     )
 
     data_source_arg_type = CLIArgumentType(
         options_list=['--data-source'],
         help='Data source for importing to Flexible Server. Based on the data source type provide the data source as mentioned below. '
-             'e.g., mysql_single: The name or resource ID of the azure MySQL single server. '
+             'e.g., mysql_single: The name or resource ID of the Azure MySQL single server. '
+             'azure_blob: The name or resource ID of the Azure blob container. The storage uri of the azure blob container. '
+             'Example: https://{blob_name}.blob.core.windows.net/{container_name}. The storage uri should not contain the sas token. '
+             'If required, sas token can be provided in "data-source-sas-token" parameter.'
+    )
+
+    data_source_backup_dir_arg_type = CLIArgumentType(
+        options_list=['--data-source-backup-dir'],
+        help='Relative path of the directory in which source backup is stored. '
+             'By default, the backup files will be read from the root of storage. '
+             'This parameter is valid for storage based data source. Example: azure_blob. '
+    )
+
+    data_source_sas_token_arg_type = CLIArgumentType(
+        options_list=['--data-source-sas-token'],
+        help='Sas token for accessing the data source. This parameter is valid for storage based data source. Example: azure_blob. '
     )
 
     mode_arg_type = CLIArgumentType(
         options_list=['--mode'],
-        arg_type=get_enum_type(['Offline']),
-        help='Mode of import. Enum values: [Offline]. Default is Offline. '
+        arg_type=get_enum_type(['Offline', 'Online']),
+        help='Mode of import. Enum values: [Offline, Online]. Default is Offline. '
     )
 
     with self.argument_context('mysql flexible-server') as c:
         c.argument('resource_group_name', arg_type=resource_group_name_type)
         c.argument('server_name', arg_type=server_name_arg_type)
 
+    # Advanced Threat Protection
+    with self.argument_context('mysql flexible-server advanced-threat-protection-setting update') as c:
+        c.argument('state',
+                   options_list=['--state'],
+                   required=True,
+                   arg_type=get_enum_type(['Enabled', 'Disabled']),
+                   help="State of server's advanced threat protection setting. ")
+
     with self.argument_context('mysql flexible-server create') as c:
         c.argument('tier', default='Burstable', arg_type=tier_arg_type)
         c.argument('sku_name', default='Standard_B1ms', arg_type=sku_name_arg_type)
         c.argument('storage_gb', default='32', arg_type=storage_gb_arg_type)
-        c.argument('version', default='5.7', arg_type=version_arg_type)
+        c.argument('version', default='8.0.21', arg_type=version_arg_type)
         c.argument('iops', arg_type=iops_arg_type)
         c.argument('auto_grow', default='Enabled', arg_type=auto_grow_arg_type)
-        c.argument('auto_scale_iops', default='Disabled', arg_type=auto_scale_iops_arg_type)
+        c.argument('auto_scale_iops', default='Enabled', arg_type=auto_scale_iops_arg_type)
+        c.argument('accelerated_logs', arg_type=accelerated_logs_arg_type)
         c.argument('backup_retention', default=7, arg_type=mysql_backup_retention_arg_type)
         c.argument('backup_byok_identity', arg_type=backup_identity_arg_type)
+        c.argument('backup_interval', arg_type=backup_interval_arg_type)
         c.argument('backup_byok_key', arg_type=backup_key_arg_type)
         c.argument('byok_identity', arg_type=identity_arg_type)
         c.argument('byok_key', arg_type=key_arg_type)
@@ -291,6 +372,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('public_access', arg_type=public_access_create_arg_type)
         c.argument('vnet', arg_type=vnet_arg_type)
         c.argument('vnet_address_prefix', arg_type=vnet_address_prefix_arg_type)
+        c.argument('storage_redundancy', arg_type=storage_redundancy_arg_type)
         c.argument('subnet', arg_type=subnet_arg_type)
         c.argument('subnet_address_prefix', arg_type=subnet_address_prefix_arg_type)
         c.argument('private_dns_zone_arguments', private_dns_zone_arguments_arg_type)
@@ -298,24 +380,26 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('tags', tags_type)
         c.argument('standby_availability_zone', arg_type=standby_availability_zone_arg_type)
         c.argument('database_name', arg_type=database_name_arg_type)
+        c.argument('database_port', arg_type=database_port_arg_type)
+        c.argument('maintenance_policy_patch_strategy', arg_type=maintenance_policy_patch_strategy_arg_type)
         c.argument('yes', arg_type=yes_arg_type)
 
     with self.argument_context('mysql flexible-server import create') as c:
-        c.argument('tier', default='Burstable', arg_type=tier_arg_type)
-        c.argument('sku_name', default='Standard_B1ms', arg_type=sku_name_arg_type)
-        c.argument('storage_gb', default='32', arg_type=storage_gb_arg_type)
-        c.argument('version', default='5.7', arg_type=version_arg_type)
+        c.argument('tier', arg_type=tier_arg_type)
+        c.argument('sku_name', arg_type=sku_name_arg_type)
+        c.argument('storage_gb', arg_type=storage_gb_arg_type)
+        c.argument('version', arg_type=version_arg_type)
         c.argument('iops', arg_type=iops_arg_type)
-        c.argument('auto_grow', default='Enabled', arg_type=auto_grow_arg_type)
+        c.argument('auto_grow', arg_type=auto_grow_arg_type)
         c.argument('auto_scale_iops', default='Disabled', arg_type=auto_scale_iops_arg_type)
-        c.argument('backup_retention', default=7, arg_type=mysql_backup_retention_arg_type)
+        c.argument('backup_retention', arg_type=mysql_backup_retention_arg_type)
         c.argument('backup_byok_identity', arg_type=backup_identity_arg_type)
         c.argument('backup_byok_key', arg_type=backup_key_arg_type)
         c.argument('byok_identity', arg_type=identity_arg_type)
         c.argument('byok_key', arg_type=key_arg_type)
-        c.argument('geo_redundant_backup', default='Disabled', arg_type=geo_redundant_backup_arg_type)
+        c.argument('geo_redundant_backup', arg_type=geo_redundant_backup_arg_type)
         c.argument('location', arg_type=get_location_type(self.cli_ctx))
-        c.argument('administrator_login', default=generate_username(), arg_type=administrator_login_arg_type)
+        c.argument('administrator_login', arg_type=administrator_login_arg_type)
         c.argument('administrator_login_password', arg_type=administrator_login_password_arg_type)
         c.argument('high_availability', arg_type=high_availability_arg_type, default="Disabled")
         c.argument('public_access', arg_type=public_access_create_arg_type)
@@ -330,7 +414,12 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('yes', arg_type=yes_arg_type)
         c.argument('data_source_type', arg_type=data_source_type_arg_type)
         c.argument('data_source', arg_type=data_source_arg_type)
-        c.argument('mode', arg_type=mode_arg_type)
+        c.argument('data_source_backup_dir', arg_type=data_source_backup_dir_arg_type)
+        c.argument('data_source_sas_token', arg_type=data_source_sas_token_arg_type)
+        c.argument('mode', default='Offline', arg_type=mode_arg_type)
+
+    with self.argument_context('mysql flexible-server import stop-replication') as c:
+        c.argument('server_name', arg_type=server_name_arg_type)
 
     with self.argument_context('mysql flexible-server delete') as c:
         c.argument('yes', arg_type=yes_arg_type)
@@ -342,6 +431,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('vnet_address_prefix', arg_type=vnet_address_prefix_arg_type)
         c.argument('subnet', arg_type=subnet_arg_type)
         c.argument('subnet_address_prefix', arg_type=subnet_address_prefix_arg_type)
+        c.argument('storage_redundancy', arg_type=storage_redundancy_arg_type)
         c.argument('private_dns_zone_arguments', private_dns_zone_arguments_arg_type)
         c.argument('zone', arg_type=zone_arg_type)
         c.argument('tags', tags_type)
@@ -350,8 +440,11 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('tier', arg_type=tier_arg_type)
         c.argument('storage_gb', arg_type=storage_gb_arg_type)
         c.argument('auto_grow', arg_type=auto_grow_arg_type)
+        c.argument('accelerated_logs', arg_type=accelerated_logs_arg_type)
+        c.argument('faster_restore', arg_type=faster_restore_arg_type)
         c.argument('backup_retention', arg_type=mysql_backup_retention_arg_type)
         c.argument('geo_redundant_backup', arg_type=geo_redundant_backup_arg_type)
+        c.argument('database_port', arg_type=database_port_arg_type)
         c.argument('public_access', options_list=['--public-access'], arg_type=get_enum_type(['Enabled', 'Disabled']), help='Determines the public access. ')
 
     with self.argument_context('mysql flexible-server geo-restore') as c:
@@ -370,6 +463,8 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('tier', arg_type=tier_arg_type)
         c.argument('storage_gb', arg_type=storage_gb_arg_type)
         c.argument('auto_grow', arg_type=auto_grow_arg_type)
+        c.argument('accelerated_logs', arg_type=accelerated_logs_arg_type)
+        c.argument('storage_redundancy', arg_type=storage_redundancy_arg_type)
         c.argument('backup_retention', arg_type=mysql_backup_retention_arg_type)
         c.argument('geo_redundant_backup', arg_type=geo_redundant_backup_arg_type)
         c.argument('public_access', options_list=['--public-access'], arg_type=get_enum_type(['Enabled', 'Disabled']), help='Determines the public access. ')
@@ -388,6 +483,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('byok_identity', arg_type=identity_arg_type)
         c.argument('auto_grow', arg_type=auto_grow_arg_type)
         c.argument('auto_scale_iops', arg_type=auto_scale_iops_arg_type)
+        c.argument('accelerated_logs', arg_type=accelerated_logs_arg_type)
         c.argument('replication_role', options_list=['--replication-role'], help='The replication role of the server.')
         c.argument('iops', arg_type=iops_arg_type)
         c.argument('backup_retention', arg_type=mysql_backup_retention_arg_type)
@@ -396,6 +492,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('backup_byok_key', arg_type=backup_key_arg_type)
         c.argument('disable_data_encryption', arg_type=disable_data_encryption_arg_type)
         c.argument('public_access', arg_type=public_access_update_arg_type)
+        c.argument('maintenance_policy_patch_strategy', arg_type=maintenance_policy_patch_strategy_arg_type)
 
     with self.argument_context('mysql flexible-server upgrade') as c:
         c.argument('version', arg_type=mysql_version_upgrade_arg_type)
@@ -407,8 +504,12 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
     with self.argument_context('mysql flexible-server list-skus') as c:
         c.argument('location', arg_type=get_location_type(self.cli_ctx))
 
+    with self.argument_context('mysql flexible-server detach-vnet') as c:
+        c.argument('public_network_access', options_list=['--public-network-access'], arg_type=get_enum_type(['Enabled', 'Disabled']), help='Determines the public access after vnet detach. ')
+        c.argument('yes', arg_type=yes_arg_type)
+
     # flexible-server parameter
-    for scope in ['list', 'set', 'show']:
+    for scope in ['list', 'set', 'show', 'set-batch']:
         argument_context_string = 'mysql flexible-server parameter {}'.format(scope)
         with self.argument_context(argument_context_string) as c:
             if scope == "list":
@@ -425,6 +526,10 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('value', options_list=['--value', '-v'], help='Value of the configuration.')
         c.argument('source', options_list=['--source'], help='Source of the configuration.')
 
+    with self.argument_context('mysql flexible-server parameter set-batch') as c:
+        c.argument('configuration_list', action=AddArgs, nargs='*', options_list=['--args'], required=True, help='List of the configuration key-value pair.')
+        c.argument('source', options_list=['--source'], required=False, help='Source of the configuration.')
+
     # firewall-rule
     for scope in ['create', 'delete', 'list', 'show', 'update']:
         argument_context_string = 'mysql flexible-server firewall-rule {}'.format(scope)
@@ -439,7 +544,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         argument_context_string = 'mysql flexible-server firewall-rule {}'.format(scope)
         with self.argument_context(argument_context_string) as c:
             c.argument('firewall_rule_name', id_part='child_name_1', options_list=['--rule-name', '-r'], validator=firewall_rule_name_validator,
-                       help='The name of the firewall rule. If name is omitted, default name will be chosen for firewall name. The firewall rule name can only contain 0-9, a-z, A-Z, \'-\' and \'_\'. Additionally, the name of the firewall rule must be at least 3 characters and no more than 128 characters in length. ')
+                       help='The name of the firewall rule. If name is omitted, default name will be chosen for firewall name. The firewall rule name can only contain 0-9, a-z, A-Z, \'-\' and \'_\'. Additionally, the name of the firewall rule must be at least 1 character and no more than 80 characters in length. ')
             c.argument('end_ip_address', options_list=['--end-ip-address'], validator=ip_address_validator,
                        help='The end IP address of the firewall rule. Must be IPv4 format. Use value \'0.0.0.0\' to represent all Azure-internal IP addresses. ')
             c.argument('start_ip_address', options_list=['--start-ip-address'], validator=ip_address_validator,
@@ -484,6 +589,15 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('subnet', arg_type=subnet_arg_type)
         c.argument('private_dns_zone_arguments', private_dns_zone_arguments_arg_type)
         c.argument('public_access', options_list=['--public-access'], arg_type=get_enum_type(['Enabled', 'Disabled']), help='Determines the public access. ')
+        c.argument('tier', arg_type=tier_arg_type)
+        c.argument('sku_name', arg_type=sku_name_arg_type)
+        c.argument('storage_gb', arg_type=storage_gb_arg_type)
+        c.argument('iops', arg_type=iops_arg_type)
+        c.argument('storage_redundancy', arg_type=storage_redundancy_arg_type)
+        c.argument('faster_provisioning', arg_type=faster_provisioning_arg_type)
+        c.argument('database_port', arg_type=database_port_arg_type)
+        c.argument('backup_retention', arg_type=mysql_backup_retention_arg_type)
+        c.argument('geo_redundant_backup', arg_type=geo_redundant_backup_arg_type)
 
     with self.argument_context('mysql flexible-server replica stop-replication') as c:
         c.argument('server_name', arg_type=server_name_arg_type)
@@ -501,8 +615,8 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('allow_push', default=False, options_list=['--allow-push'], arg_type=get_three_state_flag(), help='Push the action yml file to the remote repository. The changes will be pushed to origin repository, speicified branch or current branch if not specified.')
 
     with self.argument_context('mysql flexible-server deploy run') as c:
-        c.argument('action_name', options_list=['--action-name'], help='The name of the github action')
-        c.argument('branch', options_list=['--branch'], help='The name of the branch you want upload github action file. The default will be your current branch.')
+        c.argument('action_name', options_list=['--action-name'], help='The name of the github action', validator=validate_action_name)
+        c.argument('branch', options_list=['--branch'], help='The name of the branch you want upload github action file. The default will be your current branch.', validator=validate_branch)
 
     with self.argument_context('mysql flexible-server server-logs download') as c:
         c.argument('server_name', id_part=None, options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
@@ -524,6 +638,11 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
     with self.argument_context('mysql flexible-server backup list') as c:
         c.argument('server_name', id_part=None, arg_type=server_name_arg_type)
 
+    # export
+    with self.argument_context('mysql flexible-server export create') as c:
+        c.argument('backup_name', options_list=['--backup-name', '-b'], help='The name of the new export backup.')
+        c.argument('sas_uri', options_list=['--sas-uri', '-u'], help='SAS URI for destination container.')
+
     # identity
     with self.argument_context('mysql flexible-server identity') as c:
         c.argument('server_name', id_part=None, options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
@@ -537,6 +656,21 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
     with self.argument_context('mysql flexible-server identity show') as c:
         c.argument('identity', options_list=['--identity', '-n'], help='Name or ID of identity to show.', validator=validate_identity)
 
+    with self.argument_context('mysql flexible-server maintenance reschedule') as c:
+        c.argument('resource_group_name', arg_type=resource_group_name_type, help='Resource Group Name of the server.')
+        c.argument('server_name', options_list=['--server-name', '-s'], help='The name of the server.')
+        c.argument('maintenance_name', options_list=['--maintenance-name', '-m'], help='The name of the maintenance.')
+        c.argument('maintenance_start_time', arg_type=maintenance_reschedule_time_arg_type, help='The new start time of the rescheduled maintenance.')
+
+    with self.argument_context('mysql flexible-server maintenance list') as c:
+        c.argument('resource_group_name', id_part=None, arg_type=resource_group_name_type, help='Resource Group Name of the server.')
+        c.argument('server_name', id_part=None, options_list=['--server-name', '-s'], help='The name of the server.')
+
+    with self.argument_context('mysql flexible-server maintenance show') as c:
+        c.argument('resource_group_name', arg_type=resource_group_name_type, help='Resource Group Name of the server.')
+        c.argument('server_name', options_list=['--server-name', '-s'], help='The name of the server.')
+        c.argument('maintenance_name', options_list=['--maintenance-name', '-m'], help='The name of the maintenance.')
+
     # ad-admin
     with self.argument_context('mysql flexible-server ad-admin') as c:
         c.argument('server_name', id_part=None, options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
