@@ -84,6 +84,8 @@ def register_providers():
     _register_one_provider("Microsoft.DocumentDB/mongoClusters", '2023-03-01-preview', True)
     _register_one_provider('Microsoft.DBforPostgreSQL/flexibleServers', '2023-06-01-preview', False)
     _register_one_provider('Microsoft.App/managedEnvironments', '2024-02-02-preview', True)
+    _register_one_provider('Microsoft.FluidRelay/fluidRelayServers', '2025-03-10-preview', True)
+    _register_one_provider('Microsoft.VideoIndexer/accounts', '2025-04-01', True)
 
 
 def _register_one_provider(provider, api_version, support_list_or_not, resource_get_api_version=None, support_connection_operation=True):  # pylint: disable=line-too-long
