@@ -48,8 +48,8 @@ def _authorization_management_client(cli_ctx, **_):
 
 def _resource_managedapps_client_factory(cli_ctx, **_):
     from azure.cli.core.commands.client_factory import get_mgmt_service_client
-    from azure.mgmt.resource.managedapplications import ApplicationClient
-    return get_mgmt_service_client(cli_ctx, ApplicationClient)
+    from azure.cli.core.profiles import ResourceType
+    return get_mgmt_service_client(cli_ctx, ResourceType.MGMT_RESOURCE_MANAGEDAPPLICATIONS)
 
 
 def _resource_managementgroups_client_factory(cli_ctx, **_):
@@ -64,6 +64,12 @@ def _resource_templatespecs_client_factory(cli_ctx, **_):
     return get_mgmt_service_client(cli_ctx, ResourceType.MGMT_RESOURCE_TEMPLATESPECS)
 
 
+def _resource_deploymentstacks_client_factory(cli_ctx, **_):
+    from azure.cli.core.commands.client_factory import get_mgmt_service_client
+    from azure.cli.core.profiles import ResourceType
+    return get_mgmt_service_client(cli_ctx, ResourceType.MGMT_RESOURCE_DEPLOYMENTSTACKS)
+
+
 def _resource_privatelinks_client_factory(cli_ctx, **_):
     from azure.cli.core.commands.client_factory import get_mgmt_service_client
     from azure.cli.core.profiles import ResourceType
@@ -158,6 +164,10 @@ def cf_resource_templatespecs(cli_ctx, _):
     return _resource_templatespecs_client_factory(cli_ctx).template_specs
 
 
+def cf_resource_deploymentstacks(cli_ctx, _):
+    return _resource_deploymentstacks_client_factory(cli_ctx).deployment_stacks
+
+
 def cf_resource_privatelinkassociations(cli_ctx, _):
     return _resource_privatelinks_client_factory(cli_ctx).private_link_association
 
