@@ -4,7 +4,9 @@
 # --------------------------------------------------------------------------------------------
 from knack.log import get_logger
 from azure.cli.core.util import sdk_no_wait
-from azure.cli.core.azclierror import UnrecognizedArgumentError
+from azure.cli.core.azclierror import (UnrecognizedArgumentError, MutuallyExclusiveArgumentError,
+                                       RequiredArgumentMissingError)
+from .aaz.latest.search.service import Create as _SearchServiceCreate, Update as _SearchServiceUpdate
 
 logger = get_logger(__name__)
 
@@ -17,79 +19,121 @@ def _get_resource_group_location(cli_ctx, resource_group_name):
     return client.resource_groups.get(resource_group_name).location
 
 
-# pylint: disable=too-many-locals
-def create_search_service(cmd, resource_group_name, search_service_name, sku, location=None, partition_count=0,
-                          replica_count=0, public_network_access="enabled", ip_rules=None, identity_type=None,
-                          hosting_mode="default", disable_local_auth=None, auth_options=None,
-                          aad_auth_failure_mode=None, no_wait=False):
-    """
-    Creates a Search service in the given resource group.
+class SearchServiceCreate(_SearchServiceCreate):
 
-    :param resource_group_name: Name of resource group.
-    :param search_service_name: Name of the search service.
-    :param sku: The SKU of the search service, which determines price tier and capacity limits.
-    :param location: Geographic location of the resource.
-    :param partition_count: Number of partitions in the search service.
-    :param replica_count: Number of replicas in the search service.
-    :param public_network_access: Public accessibility to the search service;
-                                  allowed values are "enabled" or "disabled".
-    :param ip_rules: Public IP(v4) addresses or CIDR ranges to the search service, seperated by comma or semicolon;
-                     these IP rules are applicable only when --public-network-access is "enabled".
-    :param identity_type: The identity type; possible values include: "None", "SystemAssigned".
-    :param hosting_mode: The hosting mode; possible values include: "default", "highDensity";
-                     Note that "highDensity" is only applicable to the standard3 SKU.
-    :param disable_local_auth: If calls to the search service will not be permitted to utilize API keys for
-                    authentication;
-                     This cannot be combined with auth_options.
-    :param auth_options: Options for authenticating calls to the search service;
-                    possible values include"aadOrApiKey", "apiKeyOnly";
-                     This cannot be combined with disable_local_auth.
-    :param aad_auth_failure_mode: Describes response code from calls to the search service that
-                     failed authentication; possible values include "http401WithBearerChallenge", "http403";
-                     This cannot be combined with disable_local_auth.
-    """
-    from azure.mgmt.search.models import SearchService, Sku, NetworkRuleSet, IpRule, Identity
-    from azure.cli.command_modules.search._client_factory import cf_search_services
-    import re
+    # pylint: disable=protected-access
+    @classmethod
+    def _build_arguments_schema(cls, *args, **kwargs):
+        from azure.cli.core.aaz import AAZStrArg
+        args_schema = super()._build_arguments_schema(*args, **kwargs)
+        args_schema.ip_rules = AAZStrArg(
+            arg_group="Properties",
+            options=['--ip-rules'],
+            help="Some help"
+        )
+        args_schema.auth_options = AAZStrArg(
+            arg_group="Properties",
+            options=['--auth-options'],
+            help="Some Help",
+            enum=["aadOrApiKey", "apiKeyOnly"],
+        )
+        args_schema.ip_rules_internal._registered = False
+        args_schema.api_key_only._registered = False
+        return args_schema
 
-    _client = cf_search_services(cmd.cli_ctx, None)
-    if location is None:
-        location = _get_resource_group_location(cmd.cli_ctx, resource_group_name)
+    def pre_operations(self):
+        from azure.cli.core.aaz import has_value
+        import re
+        args = self.ctx.args
 
-    _search = SearchService(location=location, sku=Sku(name=sku.lower()))
+        if args.hosting_mode == "highDensity" and args.sku != "standard3":
+            raise UnrecognizedArgumentError(
+                "SearchService.HostingMode: highDensity is only allowed when sku is standard3")
 
-    replica_count = int(replica_count)
-    partition_count = int(partition_count)
-    if replica_count > 0:
-        _search.replica_count = replica_count
-    if partition_count > 0:
-        _search.partition_count = partition_count
-    if (public_network_access.lower() not in ["enabled", "disabled"]):
-        raise UnrecognizedArgumentError(
-            "SearchService.PublicNetworkAccess: only [""enabled"", ""disabled""] are allowed")
-    if (hosting_mode not in ["default", "highDensity"]):
-        raise UnrecognizedArgumentError(
-            "SearchService.HostingMode: only [""default"", ""highDensity""] are allowed")
-    if (hosting_mode == "highDensity" and sku.lower() != "standard3"):
-        raise UnrecognizedArgumentError(
-            "SearchService.HostingMode: ""highDensity"" is only allowed when sku is ""standard3""")
+        if has_value(args.ip_rules):
+            ip_rules = re.split(';|,', args.ip_rules.to_serialized_data())
+            args.ip_rules_internal = [{"value": ip_rule} for ip_rule in ip_rules]
 
-    _search.public_network_access = public_network_access
-    _search.hosting_mode = hosting_mode
+        if has_value(args.disable_local_auth) and args.disable_local_auth.to_serialized_data() is True:
+            if has_value(args.auth_options):
+                raise MutuallyExclusiveArgumentError("Both the DisableLocalAuth and AuthOptions parameters "
+                                                     "can't be given at the same time")
+            if has_value(args.aad_auth_failure_mode):
+                raise MutuallyExclusiveArgumentError("Both the DisableLocalAuth and AadAuthFailureMode parameters "
+                                                     "can't be given at the same time")
+        if has_value(args.auth_options):
+            if args.auth_options == "apiKeyOnly":
+                if has_value(args.aad_auth_failure_mode):
+                    raise MutuallyExclusiveArgumentError(
+                        "Both an AuthOptions value of apiKeyOnly and an AadAuthFailureMode "
+                        "can't be given at the same time")
+                args.api_key_only = {}
+            elif args.auth_options == "aadOrApiKey" and not has_value(args.aad_auth_failure_mode):
+                raise RequiredArgumentMissingError("An AuthOptions value of aadOrApiKey requires "
+                                                   "an AadAuthFailureMode parameter")
 
-    if ip_rules:
-        _ip_rules = []
-        _ip_rules_array = re.split(';|,', ip_rules)
-        for _ip_rule in _ip_rules_array:
-            if _ip_rule:
-                _ip_rules.append(IpRule(value=_ip_rule))
-        _search.network_rule_set = NetworkRuleSet(ip_rules=_ip_rules)
-    if identity_type:
-        _identity = Identity(type=identity_type)
-        _search.identity = _identity
-    setup_search_auth(_search, disable_local_auth, auth_options, aad_auth_failure_mode)
 
-    return sdk_no_wait(no_wait, _client.begin_create_or_update, resource_group_name, search_service_name, _search)
+class SearchServiceUpdate(_SearchServiceUpdate):
+
+    # pylint: disable=protected-access
+    @classmethod
+    def _build_arguments_schema(cls, *args, **kwargs):
+        from azure.cli.core.aaz import AAZStrArg
+        args_schema = super()._build_arguments_schema(*args, **kwargs)
+        args_schema.ip_rules = AAZStrArg(
+            arg_group="Properties",
+            options=['--ip-rules'],
+            help="Some help",
+            nullable=True,  # allow to remove all the value when it's assigned by null
+        )
+        args_schema.auth_options = AAZStrArg(
+            arg_group="Properties",
+            options=['--auth-options'],
+            help="Some Help",
+            enum=["aadOrApiKey", "apiKeyOnly"],
+        )
+
+        args_schema.ip_rules_internal._registered = False
+        args_schema.api_key_only._registered = False
+        return args_schema
+
+    def pre_operations(self):
+        from azure.cli.core.aaz import has_value
+        import re
+        args = self.ctx.args
+
+        if has_value(args.ip_rules):
+            if args.ip_rules.to_serialized_data() is None or args.ip_rules in [';', ',']:
+                # cleanup all ip_rules
+                args.ip_rules_internal = None
+            else:
+                ip_rules = re.split(';|,', args.ip_rules.to_serialized_data())
+                args.ip_rules_internal = [{"value": ip_rule} for ip_rule in ip_rules]
+
+        if has_value(args.disable_local_auth) and args.disable_local_auth.to_serialized_data() is True:
+            if has_value(args.auth_options):
+                raise MutuallyExclusiveArgumentError("Both the DisableLocalAuth and AuthOptions parameters "
+                                                     "can't be given at the same time")
+            if has_value(args.aad_auth_failure_mode):
+                raise MutuallyExclusiveArgumentError("Both the DisableLocalAuth and AadAuthFailureMode parameters "
+                                                     "can't be given at the same time")
+        if has_value(args.auth_options):
+            if args.auth_options == "apiKeyOnly":
+                if has_value(args.aad_auth_failure_mode):
+                    raise MutuallyExclusiveArgumentError(
+                        "Both an AuthOptions value of apiKeyOnly and an AadAuthFailureMode "
+                        "can't be given at the same time")
+                args.api_key_only = {}
+            elif args.auth_options == "aadOrApiKey" and not has_value(args.aad_auth_failure_mode):
+                raise RequiredArgumentMissingError("An AuthOptions value of aadOrApiKey requires "
+                                                   "an AadAuthFailureMode parameter")
+
+    def pre_instance_update(self, instance):
+        from azure.cli.core.aaz import has_value
+        args = self.ctx.args
+        if has_value(args.auth_options):
+            # clean up current auth_options
+            instance.properties.auth_options = {}
 
 
 def update_search_service(instance, partition_count=0, replica_count=0, public_network_access=None,
@@ -129,7 +173,7 @@ def update_search_service(instance, partition_count=0, replica_count=0, public_n
     if public_network_access:
         if (public_network_access.lower() not in ["enabled", "disabled"]):
             raise UnrecognizedArgumentError(
-                "SearchService.PublicNetworkAccess: only [""enabled"", ""disabled""] are allowed")
+                "SearchService.PublicNetworkAccess: only [enabled, disabled] are allowed")
         instance.public_network_access = public_network_access
     if ip_rules:
         _ip_rules = []
@@ -267,19 +311,21 @@ def setup_search_auth(instance, disable_local_auth, auth_options, aad_auth_failu
                     possible values include "http401WithBearerChallenge", "http403";
                      This cannot be combined with disable_local_auth.
     """
-    from azure.cli.core.azclierror import MutuallyExclusiveArgumentError, RequiredArgumentMissingError
-
+    # Done in aaz by default
     if (disable_local_auth is not None and disable_local_auth not in [True, False]):
         raise UnrecognizedArgumentError(
             "SearchService.DisableLocalAuth: only [True, False] are allowed")
+    # Done by argument define
     if (auth_options is not None and auth_options not in ["aadOrApiKey", "apiKeyOnly"]):
         raise UnrecognizedArgumentError(
-            "SearchService.AuthOptions: only [""aadOrApiKey"", ""apiKeyOnly""] are allowed")
+            "SearchService.AuthOptions: only [aadOrApiKey, apiKeyOnly] are allowed")
+    # Done in aaz by default
     if (aad_auth_failure_mode is not None and aad_auth_failure_mode not in ["http401WithBearerChallenge", "http403"]):
         raise UnrecognizedArgumentError(
             "SearchService.AuthOptions.AadAuthFailureMode: only "
-            "[""http401WithBearerChallenge"", ""http403""] are allowed")
+            "[http401WithBearerChallenge, http403] are allowed")
 
+    # Done in pre_operations
     if disable_local_auth and auth_options:
         raise MutuallyExclusiveArgumentError("Both the DisableLocalAuth and AuthOptions parameters "
                                              "can't be given at the same time")
