@@ -12,7 +12,7 @@ class AzureSearchServicesTests(ScenarioTest):
     # https://vcrpy.readthedocs.io/en/latest/configuration.html#request-matching
     def setUp(self):
         self.vcr.match_on = ['scheme', 'method', 'path', 'query'] # not 'host', 'port'
-        super(AzureSearchServicesTests, self).setUp()
+        super().setUp()
 
     @ResourceGroupPreparer(name_prefix='azure_search_cli_test', location='eastus2euap')
     def test_list_private_link_resources(self, resource_group):
