@@ -3,25 +3,34 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
+import os
+import re
 import time
 from knack.log import get_logger
 from knack.util import todict, CLIError
-from msrestazure.tools import parse_resource_id
 from azure.cli.core.azclierror import (
     ValidationError,
     CLIInternalError
 )
-from azure.cli.core._profile import Profile
+# from azure.cli.core._profile import Profile
 from ._resource_config import (
     SOURCE_RESOURCES_USERTOKEN,
     TARGET_RESOURCES_USERTOKEN,
     RESOURCE
 )
-
+from azure.cli.core import get_default_cli
+from azure.mgmt.core.tools import (
+    parse_resource_id,
+    is_valid_resource_id as is_valid_resource_id_sdk
+)
 
 logger = get_logger(__name__)
 
 
+def is_valid_resource_id(value):
+    return is_valid_resource_id_sdk(value)
+
+
 def should_load_source(source):
     '''Check whether to load `az {source} connection`
     If {source} is an extension (e.g, spring-cloud), load the command group only when {source} is installed
@@ -77,34 +86,37 @@ def run_cli_cmd(cmd, retry=0, interval=0, should_retry_func=None):
     :param retry: The times to re-try
     :param interval: The seconds wait before retry
     '''
-    import json
-    import subprocess
+    output = _in_process_execute(cmd)
 
-    output = subprocess.run(cmd, shell=True, check=False,
-                            stderr=subprocess.PIPE, stdout=subprocess.PIPE)
-    logger.debug(output)
-    if output.returncode != 0 or (should_retry_func and should_retry_func(output)):
+    if output.error or (should_retry_func and should_retry_func(output)):
         if retry:
             time.sleep(interval)
             return run_cli_cmd(cmd, retry - 1, interval)
-        err = output.stderr.decode(encoding='UTF-8', errors='ignore')
         raise CLIInternalError('Command execution failed, command is: '
-                               '{}, error message is: \n {}'.format(cmd, err))
-    try:
-        return json.loads(output.stdout.decode(encoding='UTF-8', errors='ignore')) if output.stdout else None
-    except ValueError as e:
-        logger.debug(e)
-        return output.stdout or None
+                               '{}, error message is: \n {}'.format(cmd, output.error))
+    return output.result
 
 
+def _in_process_execute(command):
+    import shlex
+
+    if command.startswith('az '):
+        command = command[3:]
+
+    cli = get_default_cli()
+    cli.invoke(shlex.split(command), out_file=open(os.devnull, 'w'))  # Don't print output
+    return cli.result
+
+
+# pylint: disable=unused-argument
 def set_user_token_header(client, cli_ctx):
     '''Set user token header to work around OBO'''
 
     # pylint: disable=protected-access
     # HACK: set custom header to work around OBO
-    profile = Profile(cli_ctx=cli_ctx)
-    creds, _, _ = profile.get_raw_token()
-    client._client._config.headers_policy._headers['x-ms-serviceconnector-user-token'] = creds[1]
+    # profile = Profile(cli_ctx=cli_ctx)
+    # creds, _, _ = profile.get_raw_token()
+    # client._client._config.headers_policy._headers['x-ms-serviceconnector-user-token'] = creds[1]
     # HACK: hide token header
     client._config.logging_policy.headers_to_redact.append(
         'x-ms-serviceconnector-user-token')
@@ -123,7 +135,7 @@ def provider_is_registered(subscription=None):
     # register the provider
     subs_arg = ''
     if subscription:
-        subs_arg = '--subscription {}'.format(subscription)
+        subs_arg = '--subscription "{}"'.format(subscription)
     output = run_cli_cmd(
         'az provider show -n Microsoft.ServiceLinker {}'.format(subs_arg))
     if output.get('registrationState') == 'NotRegistered':
@@ -137,7 +149,7 @@ def register_provider(subscription=None):
 
     subs_arg = ''
     if subscription:
-        subs_arg = '--subscription {}'.format(subscription)
+        subs_arg = '--subscription "{}"'.format(subscription)
 
     # register the provider
     run_cli_cmd(
@@ -199,14 +211,15 @@ def auto_register(func, *args, **kwargs):
         raise ex
 
 
-def create_key_vault_reference_connection_if_not_exist(cmd, client, source_id, key_vault_id):
+def create_key_vault_reference_connection_if_not_exist(cmd, client, source_id, key_vault_id,
+                                                       scope=None):  # Resource.ContainerApp
     from ._validators import get_source_resource_name
 
     logger.warning('get valid key vault reference connection')
     key_vault_connections = []
     for connection in client.list(resource_uri=source_id):
         connection = todict(connection)
-        if connection.get('targetService', dict()).get('id') == key_vault_id:
+        if connection.get('targetService', {}).get('id') == key_vault_id:
             key_vault_connections.append(connection)
 
     source_name = get_source_resource_name(cmd)
@@ -229,6 +242,8 @@ def create_key_vault_reference_connection_if_not_exist(cmd, client, source_id, k
             "id": key_vault_id
         },
         'auth_info': auth_info,
+        # Container App container name
+        'scope': scope,
         # Key Vault Configuration are same across all client types
         'client_type': CLIENT_TYPE.Dotnet,
     }
@@ -246,77 +261,129 @@ def create_key_vault_reference_connection_if_not_exist(cmd, client, source_id, k
 
 
 def get_auth_if_no_valid_key_vault_connection(source_name, source_id, key_vault_connections):
-    auth_type = 'systemAssignedIdentity'
-    client_id = None
-    subscription_id = None
+    if source_name == RESOURCE.WebApp:
+        return get_auth_if_no_valid_key_vault_connection_for_webapp(source_id, key_vault_connections)
 
+    if source_name == RESOURCE.ContainerApp:
+        return get_auth_if_no_valid_key_vault_connection_for_containerapp(key_vault_connections)
+
+    # any connection with csi enabled is a valid connection
+    if source_name == RESOURCE.KubernetesCluster:
+        for connection in key_vault_connections:
+            if connection.get('targetService', {}).get(
+                    'resourceProperties', {}).get('connectAsKubernetesCsiDriver'):
+                return
+        return {'authType': 'userAssignedIdentity'}
+
+    # other source types
     if key_vault_connections:
-        from msrestazure.tools import (
-            is_valid_resource_id
-        )
+        logger.warning('key vault reference connection: %s',
+                       key_vault_connections[0].get('id'))
+        return
 
-        # https://docs.microsoft.com/azure/app-service/app-service-key-vault-references
-        if source_name == RESOURCE.WebApp:
+    return {'authType': 'systemAssignedIdentity'}
+
+
+# https://learn.microsoft.com/azure/app-service/app-service-key-vault-references
+def get_auth_if_no_valid_key_vault_connection_for_webapp(source_id, key_vault_connections):
+
+    try:
+        webapp = run_cli_cmd(
+            'az rest -u "{}?api-version=2020-09-01" -o json'.format(source_id))
+        reference_identity = webapp.get(
+            'properties').get('keyVaultReferenceIdentity')
+    except Exception as e:
+        raise ValidationError('{}. Unable to get "properties.keyVaultReferenceIdentity" from {}.'
+                              'Please check your source id is correct.'.format(e, source_id))
+
+    if is_valid_resource_id(reference_identity):  # User Identity
+        auth_type = 'userAssignedIdentity'
+        segments = parse_resource_id(reference_identity)
+        subscription_id = segments.get('subscription')
+        try:
+            identity = webapp.get('identity').get(
+                'userAssignedIdentities').get(reference_identity)
+            client_id = identity.get('clientId')
+        except Exception:  # pylint: disable=broad-except
             try:
-                webapp = run_cli_cmd(
-                    'az rest -u {}?api-version=2020-09-01 -o json'.format(source_id))
-                reference_identity = webapp.get(
-                    'properties').get('keyVaultReferenceIdentity')
-            except Exception as e:
-                raise ValidationError('{}. Unable to get "properties.keyVaultReferenceIdentity" from {}.'
-                                      'Please check your source id is correct.'.format(e, source_id))
+                identity = run_cli_cmd(
+                    'az identity show --ids "{}" -o json'.format(reference_identity))
+                client_id = identity.get('clientId')
+            except Exception:  # pylint: disable=broad-except
+                pass
+        if not subscription_id or not client_id:
+            raise ValidationError('Unable to get subscriptionId or clientId'
+                                  'of the keyVaultReferenceIdentity {}'.format(reference_identity))
+        for connection in key_vault_connections:
+            auth_info = connection.get('authInfo')
+            if auth_info.get('clientId') == client_id and auth_info.get('subscriptionId') == subscription_id:
+                logger.warning(
+                    'key vault reference connection: %s', connection.get('id'))
+                return
+        return {'authType': auth_type, 'clientId': client_id, 'subscriptionId': subscription_id}
 
-            if is_valid_resource_id(reference_identity):  # User Identity
-                auth_type = 'userAssignedIdentity'
-                segments = parse_resource_id(reference_identity)
-                subscription_id = segments.get('subscription')
-                try:
-                    identity = webapp.get('identity').get(
-                        'userAssignedIdentities').get(reference_identity)
-                    client_id = identity.get('clientId')
-                except Exception:  # pylint: disable=broad-except
-                    try:
-                        identity = run_cli_cmd(
-                            'az identity show --ids {} -o json'.format(reference_identity))
-                        client_id = identity.get('clientId')
-                    except Exception:  # pylint: disable=broad-except
-                        pass
-                if not subscription_id or not client_id:
-                    raise ValidationError('Unable to get subscriptionId or clientId'
-                                          'of the keyVaultReferenceIdentity {}'.format(reference_identity))
-                for connection in key_vault_connections:
-                    auth_info = connection.get('authInfo')
-                    if auth_info.get('clientId') == client_id and auth_info.get('subscriptionId') == subscription_id:
-                        logger.warning(
-                            'key vault reference connection: %s', connection.get('id'))
-                        return
-            else:  # System Identity
-                for connection in key_vault_connections:
-                    if connection.get('authInfo').get('authType') == auth_type:
-                        logger.warning(
-                            'key vault reference connection: %s', connection.get('id'))
-                        return
+    # System Identity
+    auth_type = 'systemAssignedIdentity'
+    for connection in key_vault_connections:
+        if connection.get('authInfo').get('authType') == auth_type:
+            logger.warning(
+                'key vault reference connection: %s', connection.get('id'))
+            return
+    return {'authType': auth_type}
 
-        # any connection with csi enabled is a valid connection
-        elif source_name == RESOURCE.KubernetesCluster:
-            for connection in key_vault_connections:
-                if connection.get('target_service', dict()).get(
-                        'resource_properties', dict()).get('connect_as_kubernetes_csi_driver'):
-                    return
-            return {'authType': 'userAssignedIdentity'}
 
-        else:
-            logger.warning('key vault reference connection: %s',
-                           key_vault_connections[0].get('id'))
+def get_auth_if_no_valid_key_vault_connection_for_containerapp(key_vault_connections):
+    auth_type = 'systemAssignedIdentity'  # Use system identity by default
+    for connection in key_vault_connections:
+        if connection.get('authInfo').get('authType') == auth_type:
+            logger.warning(
+                'key vault reference connection: %s', connection.get('id'))
+            return
+    return {'authType': auth_type}
+
+
+def create_app_config_connection_if_not_exist(cmd, client, source_id, app_config_id,
+                                              scope=None):  # Resource.ContainerApp
+    from ._validators import get_source_resource_name
+
+    logger.warning('looking for valid app configuration connections')
+    for connection in client.list(resource_uri=source_id):
+        connection = todict(connection)
+        if connection.get('targetService', {}).get('id') == app_config_id:
+            logger.warning('Valid app configuration connection found.')
             return
 
-    auth_info = {
-        'authType': auth_type
+    logger.warning('no valid app configuration connection found. Creating with system identity...')
+
+    from ._resource_config import (
+        CLIENT_TYPE
+    )
+
+    connection_name = generate_random_string(prefix='appconfig_')
+    parameters = {
+        'target_service': {
+            "type": "AzureResource",
+            "id": app_config_id
+        },
+        'auth_info': {
+            'authType': 'systemAssignedIdentity'
+        },
+        # Container App container name
+        'scope': scope,
+        'client_type': CLIENT_TYPE.Blank,
     }
-    if client_id and subscription_id:
-        auth_info['clientId'] = client_id
-        auth_info['subscriptionId'] = subscription_id
-    return auth_info
+
+    source_name = get_source_resource_name(cmd)
+    if source_name == RESOURCE.KubernetesCluster:
+        parameters['target_service']['resource_properties'] = {
+            'type': 'KeyVault',
+            'connect_as_kubernetes_csi_driver': True,
+        }
+
+    return auto_register(client.begin_create_or_update,
+                         resource_uri=source_id,
+                         linker_name=connection_name,
+                         parameters=parameters)
 
 
 def is_packaged_installed(package_name):
@@ -329,17 +396,24 @@ def is_packaged_installed(package_name):
 
 
 def get_object_id_of_current_user():
-    signed_in_user = run_cli_cmd('az account show').get('user')
+    signed_in_user_info = run_cli_cmd('az account show -o json')
+    if not isinstance(signed_in_user_info, dict):
+        raise CLIInternalError(
+            f"Can't parse login user information {signed_in_user_info}")
+    signed_in_user = signed_in_user_info.get('user')
     user_type = signed_in_user.get('type')
+    if not user_type or not signed_in_user.get('name'):
+        raise CLIInternalError(
+            f"Can't get user type or name from signed-in user {signed_in_user}")
     try:
         if user_type == 'user':
-            user_info = run_cli_cmd('az ad signed-in-user show')
+            user_info = run_cli_cmd('az ad signed-in-user show -o json')
             user_object_id = user_info.get('objectId') if user_info.get(
                 'objectId') else user_info.get('id')
             return user_object_id
         if user_type == 'servicePrincipal':
             user_info = run_cli_cmd(
-                f'az ad sp show --id {signed_in_user.get("name")}')
+                f'az ad sp show --id "{signed_in_user.get("name")}" -o json')
             user_object_id = user_info.get('id')
             return user_object_id
     except CLIInternalError as e:
@@ -351,7 +425,8 @@ def get_object_id_of_current_user():
 
 def get_cloud_conn_auth_info(secret_auth_info, secret_auth_info_auto,
                              user_identity_auth_info, system_identity_auth_info,
-                             service_principal_auth_info_secret, new_addon):
+                             service_principal_auth_info_secret, new_addon,
+                             auth_action=None, config_action=None, target_type=None):
     all_auth_info = []
     if secret_auth_info is not None:
         all_auth_info.append(secret_auth_info)
@@ -363,9 +438,16 @@ def get_cloud_conn_auth_info(secret_auth_info, secret_auth_info_auto,
         all_auth_info.append(system_identity_auth_info)
     if service_principal_auth_info_secret is not None:
         all_auth_info.append(service_principal_auth_info_secret)
+    if len(all_auth_info) == 0:
+        if (auth_action == 'optOutAllAuth' and config_action == 'optOut') \
+           or target_type == RESOURCE.ContainerApp:
+            return None
+        raise ValidationError('At least one auth info is needed')
     if not new_addon and len(all_auth_info) != 1:
         raise ValidationError('Only one auth info is needed')
     auth_info = all_auth_info[0] if len(all_auth_info) == 1 else None
+    if auth_info is not None and auth_action is not None:
+        auth_info.update({'auth_mode': auth_action})
     return auth_info
 
 
@@ -435,3 +517,68 @@ def _install_extension(cmd, extension_name):
     except Exception:  # nopa pylint: disable=broad-except
         return False
     return True
+
+
+def springboot_migration_warning(require_update=False, check_version=False, both_version=False):
+    warning_message = "It is recommended to use Spring Cloud Azure version 4.0 and above. \
+The configurations in the format of \"azure.cosmos.*\" from Spring Cloud Azure 3.x will no longer be supported after 1st July, 2024. \
+Please refer to https://microsoft.github.io/spring-cloud-azure/current/reference/html/appendix.html\
+#configuration-spring-cloud-azure-starter-data-cosmos for more details."
+
+    update_message = "\nPlease update your connection to include the configurations for the newer version."
+
+    check_version_message = "\nManaged identity and service principal are only supported \
+in Spring Cloud Azure version 4.0 and above. Please check your Spring Cloud Azure version. \
+Learn more at https://spring.io/projects/spring-cloud-azure#overview"
+    both_version_message = "\nTwo sets of configuration properties will be configured \
+according to Spring Cloud Azure version 3.x and 4.x. \
+Learn more at https://spring.io/projects/spring-cloud-azure#overview"
+
+    if require_update:
+        warning_message += update_message
+    if check_version:
+        warning_message += check_version_message
+    if both_version:
+        warning_message += both_version_message
+
+    return warning_message
+
+
+# LinkerResource Model is converted into dict in update flow,
+# which conflicts with the default behavior of creation wrt the key name format.
+def get_auth_type_for_update(authInfo):
+    if authInfo is None:
+        return None
+    if 'auth_type' in authInfo:
+        return authInfo['auth_type']
+    return authInfo['authType']
+
+
+def get_secret_type_for_update(authInfo):
+    if 'secret_info' in authInfo:
+        return authInfo['secret_info']['secret_type']
+    if 'secretInfo' in authInfo:
+        return authInfo['secretInfo']['secretType']
+    return ''
+
+
+# Decorator for AKS configurations.
+def is_aks_linker_by_id(resource_id):
+    pattern = r'/subscriptions/([^/]+)/resourceGroups/([^/]+)/providers/Microsoft.ContainerService' + \
+        r'/managedClusters/([^/]+)/providers/Microsoft.ServiceLinker/linkers/([^/]+)'
+    return re.match(pattern, resource_id, re.IGNORECASE) is not None
+
+
+def get_aks_resource_name(linker):
+    secret_name = get_aks_resource_secret_name(linker["name"])
+    if linker["authInfo"] is not None and linker["authInfo"].get("authType") == "userAssignedIdentity" and \
+            not (linker["targetService"]["resourceProperties"] is not None and
+                 linker["targetService"]["resourceProperties"].get("connectAsKubernetesCsiDriver")):
+        service_account_name = f'sc-account-{linker["authInfo"].get("clientId")}'
+        return [secret_name, service_account_name]
+    return [secret_name]
+
+
+def get_aks_resource_secret_name(connection_name):
+    valid_name = re.sub(r'[^a-zA-Z0-9]', '', connection_name, flags=re.IGNORECASE)
+    return f'sc-{valid_name}-secret'
