@@ -23,7 +23,7 @@ from ._test_utils import CredentialReplacer, ConfigCredentialReplacer
 class KubernetesConnectionScenarioTest(ScenarioTest):
 
     def __init__(self, method_name):
-        super(KubernetesConnectionScenarioTest, self).__init__(
+        super().__init__(
             method_name,
             recording_processors=[CredentialReplacer(), ConfigCredentialReplacer()]
         )
