@@ -12,7 +12,8 @@ from azure.cli.command_modules.servicefabric._validators import (
     validate_create_service, validate_update_application,
     validate_update_managed_application, validate_update_managed_service,
     validate_create_managed_service_correlation, validate_create_managed_service_load_metric,
-    validate_update_managed_service_load_metric, validate_update_managed_service_correlation)
+    validate_update_managed_service_load_metric, validate_update_managed_service_correlation,
+    validate_network_security_rule)
 from azure.cli.core.commands.parameters import (get_enum_type,
                                                 get_three_state_flag,
                                                 resource_group_name_type,
@@ -278,8 +279,19 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
         c.argument('thumbprint', nargs='+', help='A single or Space-separated list of client certificate thumbprint(s) to be remove.')
         c.argument('common_name', nargs='+', help='A single or Space-separated list of client certificate common name(s) to be remove.')
 
-    # managed node type
+    with self.argument_context('sf managed-cluster network-security-rule', validator=validate_network_security_rule) as c:
+        c.argument('name', help='Network security rule name')
+        c.argument('access', arg_type=get_enum_type(['allow', 'deny']), help='Allows or denies network traffic')
+        c.argument('direction', arg_type=get_enum_type(['inbound', 'outbound']), help='Network security rule direction')
+        c.argument('description', help='Network security rule description')
+        c.argument('priority', type=int, help='Integer that shows priority for rule')
+        c.argument('protocol', arg_type=get_enum_type(['tcp', 'https', 'http', 'udp', 'icmp', 'ah', 'esp', 'any']), help='Network protocol')
+        c.argument('source_port_ranges', nargs='+', help='A single or space separated list of source port ranges')
+        c.argument('dest_port_ranges', nargs='+', help='A single or space separated list of destination port ranges')
+        c.argument('source_addr_prefixes', nargs='+', help='The CIDR or source IP ranges. A single or space separated list of source address prefixes')
+        c.argument('dest_addr_prefixes', nargs='+', help='CIDR or destination IP ranges. A single or space separated list of destination address prefixes')
 
+    # managed node type
     capacity = CLIArgumentType(
         options_list=['--capacity'],
         action=AddNodeTypeCapacityAction,
@@ -300,7 +312,7 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
         c.argument('primary', arg_type=get_three_state_flag(), help='Specify if the node type is primary. On this node type will run system services. Only one node type should be marked as primary. Primary node type cannot be deleted or changed for existing clusters.')
         c.argument('disk_size', type=int, options_list=['--disk-size', '--data-disk-size'], help='Disk size for each vm in the node type in GBs.', default=100)
         c.argument('disk_type', arg_type=get_enum_type(DiskType), options_list=['--disk-type', '--data-disk-type'],
-                   help='Managed data disk type. IOPS and throughput are given by the disk size, to see more information go to https://docs.microsoft.com/azure/virtual-machines/disks-types. Default StandardSSD_LRS'
+                   help='Managed data disk type. IOPS and throughput are given by the disk size, to see more information go to https://learn.microsoft.com/azure/virtual-machines/disks-types. Default StandardSSD_LRS'
                    'Standard_LRS: Standard HDD locally redundant storage. Best for backup, non-critical, and infrequent access.'
                    'StandardSSD_LRS: Standard SSD locally redundant storage. Best for web servers, lightly used enterprise applications and dev/test.'
                    'Premium_LRS: Premium SSD locally redundant storage. Best for production and performance sensitive workloads.')
@@ -336,7 +348,7 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
 
     with self.argument_context('sf managed-node-type vm-secret') as c:
         c.argument('source_vault_id', help='Key Vault resource id containing the certificates.')
-        c.argument('certificate_url', help='This is the URL of a certificate that has been uploaded to Key Vault as a secret. For adding a secret to the Key Vault, see [Add a key or secret to the key vault](https://docs.microsoft.com/azure/key-vault/key-vault-get-started/#add). In this case, your certificate needs to be It is the Base64 encoding of the following JSON Object which is encoded in UTF-8: <br><br> {<br>  \"data\":\"<Base64-encoded-certificate>\",<br>  \"dataType\":\"pfx\",<br>  \"password\":\"<pfx-file-password>\"<br>}/')
+        c.argument('certificate_url', help='This is the URL of a certificate that has been uploaded to Key Vault as a secret. For adding a secret to the Key Vault, see [Add a key or secret to the key vault](https://learn.microsoft.com/azure/key-vault/key-vault-get-started/#add). In this case, your certificate needs to be It is the Base64 encoding of the following JSON Object which is encoded in UTF-8: `<br><br> {<br>  \"data\":\"<Base64-encoded-certificate>\",<br>  \"dataType\":\"pfx\",<br>  \"password\":\"<pfx-file-password>\"<br>}/`')
         c.argument('certificate_store', help='Specifies the certificate store on the Virtual Machine to which the certificate should be added. The specified certificate store is implicitly in the LocalMachine account.')
 
     # managed-application-type
