@@ -22,9 +22,9 @@ class ServiceFabricManagedApplicationTests(ScenarioTest):
             'vm_password': self.create_random_name('Pass@', 9),
             'app_type_name': 'VotingType',
             'v1': '1.0.0',
-            'app_package_v1': 'https://azclistaccounttest.blob.core.windows.net/azclicont/Voting.sfpkg?sp=r&st=2024-03-11T19:56:24Z&se=2024-04-07T03:56:24Z&sv=2022-11-02&sr=b&sig=hi56byw0jYpSLnJtMNemqHe92cZTMJgMHyeGa7GtN9E%3D',
+            'app_package_v1': 'https://sfmccliapptest.blob.core.windows.net/votingcont/Voting.sfpkg?sp=racwdyti&st=2024-10-28T05:39:21Z&se=2024-11-09T14:39:21Z&sv=2022-11-02&sr=b&sig=%2Fla1dP9YB3rLuyi5Nb0i6XDtTZSWb16IiUA%2BA7PLy4Q%3D',
             'v2': '2.0.0',
-            'app_package_v2': 'https://azclistaccounttest.blob.core.windows.net/azclicont/Voting.2.0.0.sfpkg?sp=r&st=2024-03-11T19:57:12Z&se=2024-04-07T03:57:12Z&sv=2022-11-02&sr=b&sig=gHhkx%2Fvd3ddWG5Nr%2FfZM8yuUqmlrL67j%2BZ3rxLLVf1k%3D',
+            'app_package_v2': 'https://sfmccliapptest.blob.core.windows.net/votingcont/Voting.2.0.0.sfpkg?sp=racwdyti&st=2024-10-28T05:42:23Z&se=2024-11-09T14:42:23Z&sv=2022-11-02&sr=b&sig=hF2%2F2%2BoVNA6VX6Rsg50OPWJS%2FPcRSpuIPg%2BMdEyvRNc%3D',
             'app_name': self.create_random_name('testApp', 11),
             'stateful_service_type': 'VotingDataType',
             'stateless_service_type': 'VotingWebType',
@@ -67,9 +67,9 @@ class ServiceFabricManagedApplicationTests(ScenarioTest):
             'vm_password': self.create_random_name('Pass@', 9),
             'app_type_name': 'VotingType',
             'v1': '1.0.0',
-            'app_package_v1': 'https://azclistaccounttest.blob.core.windows.net/azclicont/Voting.sfpkg?sp=r&st=2024-03-11T19:56:24Z&se=2024-04-07T03:56:24Z&sv=2022-11-02&sr=b&sig=hi56byw0jYpSLnJtMNemqHe92cZTMJgMHyeGa7GtN9E%3D',
+            'app_package_v1': 'https://sfmccliapptest.blob.core.windows.net/votingcont/Voting.sfpkg?sp=racwdyti&st=2024-10-28T05:39:21Z&se=2024-11-09T14:39:21Z&sv=2022-11-02&sr=b&sig=%2Fla1dP9YB3rLuyi5Nb0i6XDtTZSWb16IiUA%2BA7PLy4Q%3D',
             'v2': '2.0.0',
-            'app_package_v2': 'https://azclistaccounttest.blob.core.windows.net/azclicont/Voting.2.0.0.sfpkg?sp=r&st=2024-03-11T19:57:12Z&se=2024-04-07T03:57:12Z&sv=2022-11-02&sr=b&sig=gHhkx%2Fvd3ddWG5Nr%2FfZM8yuUqmlrL67j%2BZ3rxLLVf1k%3D',
+            'app_package_v2': 'https://sfmccliapptest.blob.core.windows.net/votingcont/Voting.2.0.0.sfpkg?sp=racwdyti&st=2024-10-28T05:42:23Z&se=2024-11-09T14:42:23Z&sv=2022-11-02&sr=b&sig=hF2%2F2%2BoVNA6VX6Rsg50OPWJS%2FPcRSpuIPg%2BMdEyvRNc%3D',
             'app_name': self.create_random_name('testApp', 11),
             'stateful_service_type': 'VotingDataType',
             'stateless_service_type': 'VotingWebType',
@@ -114,9 +114,9 @@ class ServiceFabricManagedApplicationTests(ScenarioTest):
             'vm_password': self.create_random_name('Pass@', 9),
             'app_type_name': 'VotingType',
             'v1': '1.0.0',
-            'app_package_v1': 'https://azclistaccounttest.blob.core.windows.net/azclicont/Voting.sfpkg?sp=r&st=2024-03-11T19:56:24Z&se=2024-04-07T03:56:24Z&sv=2022-11-02&sr=b&sig=hi56byw0jYpSLnJtMNemqHe92cZTMJgMHyeGa7GtN9E%3D',
+            'app_package_v1': 'https://sfmccliapptest.blob.core.windows.net/votingcont/Voting.sfpkg?sp=racwdyti&st=2024-10-28T05:39:21Z&se=2024-11-09T14:39:21Z&sv=2022-11-02&sr=b&sig=%2Fla1dP9YB3rLuyi5Nb0i6XDtTZSWb16IiUA%2BA7PLy4Q%3D',
             'v2': updated_version,
-            'app_package_v2': 'https://azclistaccounttest.blob.core.windows.net/azclicont/Voting.2.0.0.sfpkg?sp=r&st=2024-03-11T19:57:12Z&se=2024-04-07T03:57:12Z&sv=2022-11-02&sr=b&sig=gHhkx%2Fvd3ddWG5Nr%2FfZM8yuUqmlrL67j%2BZ3rxLLVf1k%3D',
+            'app_package_v2': 'https://sfmccliapptest.blob.core.windows.net/votingcont/Voting.2.0.0.sfpkg?sp=racwdyti&st=2024-10-28T05:42:23Z&se=2024-11-09T14:42:23Z&sv=2022-11-02&sr=b&sig=hF2%2F2%2BoVNA6VX6Rsg50OPWJS%2FPcRSpuIPg%2BMdEyvRNc%3D',
             'app_name': self.create_random_name('testApp', 11),
             'stateful_service_type': 'VotingDataType',
             'stateless_service_type': 'VotingWebType',
@@ -181,9 +181,9 @@ class ServiceFabricManagedApplicationTests(ScenarioTest):
             'vm_password': self.create_random_name('Pass@', 9),
             'app_type_name': 'VotingType',
             'v1': '1.0.0',
-            'app_package_v1': 'https://azclistaccounttest.blob.core.windows.net/azclicont/Voting.sfpkg?sp=r&st=2024-03-11T19:56:24Z&se=2024-04-07T03:56:24Z&sv=2022-11-02&sr=b&sig=hi56byw0jYpSLnJtMNemqHe92cZTMJgMHyeGa7GtN9E%3D',
+            'app_package_v1': 'https://sfmccliapptest.blob.core.windows.net/votingcont/Voting.sfpkg?sp=racwdyti&st=2024-10-28T05:39:21Z&se=2024-11-09T14:39:21Z&sv=2022-11-02&sr=b&sig=%2Fla1dP9YB3rLuyi5Nb0i6XDtTZSWb16IiUA%2BA7PLy4Q%3D',
             'v2': '2.0.0',
-            'app_package_v2': 'https://azclistaccounttest.blob.core.windows.net/azclicont/Voting.2.0.0.sfpkg?sp=r&st=2024-03-11T19:57:12Z&se=2024-04-07T03:57:12Z&sv=2022-11-02&sr=b&sig=gHhkx%2Fvd3ddWG5Nr%2FfZM8yuUqmlrL67j%2BZ3rxLLVf1k%3D',
+            'app_package_v2': 'https://sfmccliapptest.blob.core.windows.net/votingcont/Voting.2.0.0.sfpkg?sp=racwdyti&st=2024-10-28T05:42:23Z&se=2024-11-09T14:42:23Z&sv=2022-11-02&sr=b&sig=hF2%2F2%2BoVNA6VX6Rsg50OPWJS%2FPcRSpuIPg%2BMdEyvRNc%3D',
             'app_name': self.create_random_name('testApp', 11),
             'stateful_service_type': 'VotingDataType',
             'stateless_service_type': 'VotingWebType',
