@@ -80,14 +80,14 @@ class StorageBlobCopyTests(StorageScenarioMixin, LiveScenarioTest):
 
         from datetime import datetime, timedelta
         start = datetime.utcnow().strftime('%Y-%m-%dT%H:%MZ')
-        expiry = (datetime.utcnow() + timedelta(minutes=5)).strftime('%Y-%m-%dT%H:%MZ')
+        expiry = (datetime.utcnow() + timedelta(hours=1)).strftime('%Y-%m-%dT%H:%MZ')
         sas = self.storage_cmd('storage blob generate-sas -c {} -n src --permissions r --start {}'
                                ' --expiry {}', account_info, source_container, start,
                                expiry).output.strip()
 
         self.storage_cmd('storage blob copy start -b dst -c {} --source-blob src --sas-token {} --source-container {} '
-                         '--source-if-unmodified-since "2021-06-29T06:32Z" --destination-if-modified-since '
-                         '"2020-06-29T06:32Z" ', account_info, target_container, sas, source_container)
+                         '--source-if-unmodified-since {} --destination-if-modified-since {}',
+                         account_info, target_container, sas, source_container, expiry, expiry)
 
         from time import sleep, time
         start = time()
@@ -540,3 +540,76 @@ class StorageBlobCopyTests(StorageScenarioMixin, LiveScenarioTest):
                          '--destination-container {} --destination-blob {}', target_account_info,
                          source_account, source_container, source_blob, target_container, target_blob)
         self.storage_cmd('storage blob show -n {} -c {}', target_account_info, target_blob, target_container)
+
+    @ResourceGroupPreparer()
+    @StorageAccountPreparer(parameter_name='source_account', allow_shared_key_access=False)
+    @StorageAccountPreparer(parameter_name='target_account', allow_shared_key_access=False)
+    def test_storage_blob_copy_oauth(self, resource_group, source_account, target_account):
+        source_file = self.create_temp_file(16, full_random=True)
+        source_account_info = self.get_account_info(resource_group, source_account)
+        target_account_info = self.get_account_info(resource_group, target_account)
+
+        with open(source_file, 'rb') as f:
+            expect_content = f.read()
+
+        source_container = self.create_container(source_account_info, oauth=True)
+        target_container = self.create_container(target_account_info, oauth=True)
+        source_blob = 'srcblob'
+        target_blob = 'dstblob'
+
+        self.oauth_cmd('storage blob upload -c {} -f "{}" -n {} --account-name {}'.format(
+            source_container, source_file, source_blob, source_account))
+
+        self.oauth_cmd('storage blob copy start -b {} -c {} --source-blob {} --source-account-name {} '
+                       '--source-container {} --account-name {}'.format(
+            target_blob, target_container, source_blob, source_account, source_container, target_account))
+
+        from time import sleep, time
+        start = time()
+        while True:
+            # poll until copy has succeeded
+            blob = self.oauth_cmd('storage blob show -c {} -n {} --account-name {}'.format(
+                target_container, target_blob, target_account)).get_output_in_json()
+            if blob["properties"]["copy"]["status"] == "success" or time() - start > 10:
+                break
+            sleep(1)
+
+        target_file = self.create_temp_file(1)
+        self.oauth_cmd('storage blob download -c {} -n {} -f "{}" --account-name {}'.format(
+            target_container, target_blob, target_file, target_account))
+
+        with open(target_file, 'rb') as f:
+            actual_content = f.read()
+
+        self.assertEqual(expect_content, actual_content)
+
+    @ResourceGroupPreparer()
+    @StorageAccountPreparer(parameter_name='account1', kind='StorageV2', allow_shared_key_access=False, hns=True)
+    @StorageAccountPreparer(parameter_name='account2', kind='StorageV2', allow_shared_key_access=False)
+    def test_storage_blob_copy_batch_oauth(self, resource_group, account1, account2):
+        source_file = self.create_temp_file(16, full_random=False)
+        for src_account, dst_account in [(account1, account1), (account2, account2), (account1, account2),
+                                         (account2, account1)]:
+            src_account_info = self.get_account_info(resource_group, src_account)
+            dst_account_info = self.get_account_info(resource_group, dst_account)
+            src_container = self.create_container(src_account_info, oauth=True)
+            dst_container = self.create_container(dst_account_info, oauth=True)
+            dst_container_2 = self.create_container(dst_account_info, oauth=True)
+
+            blobs = ['blobğşŞ', 'blogÉ®']
+            for blob_name in blobs:
+                self.oauth_cmd('storage blob upload -c {} -f "{}" -n {} --account-name {}',
+                               src_container, source_file, blob_name, src_account)
+
+            self.oauth_cmd('storage fs directory create -f {} -n newdir --account-name {}', src_container, src_account)
+
+            # empty dir will be skipped when copy from hns to hns
+            copied_file = 2 if (src_account, dst_account) == (account1, account1) else 3
+            self.oauth_cmd('storage blob copy start-batch --destination-container {} --source-container {} '
+                           '--source-account-name {} --account-name {}', dst_container, src_container,
+                           src_account, dst_account).assert_with_checks(
+                JMESPathCheck('length(@)', copied_file))
+            self.oauth_cmd('storage blob copy start-batch --destination-container {} --pattern "blob*" '
+                           '--source-container {} --source-account-name {} --account-name {}',
+                           dst_container_2, src_container, src_account, dst_account).assert_with_checks(
+                JMESPathCheck('length(@)', 1))
