@@ -593,4 +593,66 @@ class StorageFileShareFileScenarios(StorageScenarioMixin, ScenarioTest):
         self.storage_cmd('storage file upload --share-name {} --source "{}" -p {} --disallow-trailing-dot '
                          '--connection-string {}', account_info, share, source_file, filename, connection_string)
         self.storage_cmd('storage file exists -s {} -p {} --disallow-trailing-dot', account_info, share, filename) \
-            .assert_with_checks(JMESPathCheck('exists', True))
\ No newline at end of file
+            .assert_with_checks(JMESPathCheck('exists', True))
+
+    @ResourceGroupPreparer()
+    @StorageAccountPreparer(location='eastus2euap', kind='FileStorage', sku='Premium_LRS')
+    def test_storage_file_share_nfs_scenario(self, resource_group, storage_account):
+        account_info = self.get_account_info(resource_group, storage_account)
+        share_name = self.create_random_name('share', 24)
+        self.storage_cmd('storage share create --name {} --protocol nfs', account_info, share_name)
+        self.storage_cmd('storage share show --name {}', account_info, share_name)\
+            .assert_with_checks(JMESPathCheck('protocols', ['NFS']))
+        dir_name = self.create_random_name('dir', 16)
+        self.storage_cmd('storage directory create --share-name {} --name {} --file-mode {} --owner {} --group {}',
+                         account_info, share_name, dir_name, 'rwxr--r--', '1', '2')
+        self.storage_cmd('storage directory show --share-name {} --name {}', account_info, share_name, dir_name)\
+            .assert_with_checks(JMESPathCheck('fileMode', '0744'),
+                                JMESPathCheck('owner', '1'),
+                                JMESPathCheck('group', '2'))
+
+        # test upload mode
+        source_file = self.create_temp_file(128, full_random=False)
+        file_name = 'src_file.txt'
+        file_path = dir_name + '/' + file_name
+        self.storage_cmd('storage file upload --share-name {} --source "{}" --path "{}" --file-mode {} --owner {} '
+                         '--group {}', account_info, share_name, source_file, file_path, 'rw-r--r--', '2', '3')
+        self.storage_cmd('storage file show --share-name {} --path {}', account_info, share_name, file_path) \
+            .assert_with_checks(JMESPathCheck('fileMode', '0644'),
+                                JMESPathCheck('owner', '2'),
+                                JMESPathCheck('group', '3'))
+        self.storage_cmd('storage file update --share-name {} --path "{}" --file-mode {} --owner {} '
+                         '--group {}', account_info, share_name, file_path, 'rw-rw-r--', '3', '4')
+        self.storage_cmd('storage file show --share-name {} --path {}', account_info, share_name, file_path) \
+            .assert_with_checks(JMESPathCheck('fileMode', '0664'),
+                                JMESPathCheck('owner', '3'),
+                                JMESPathCheck('group', '4'))
+
+        # test copy mode
+        dst_file_path = dir_name + '/' + 'dst_file.txt'
+        self.storage_cmd('storage file copy start --source-account-name {} --source-path {} --source-share {} '
+                         '--destination-path {} --destination-share {} --owner-copy-mode Source '
+                         '--file-mode-copy-mode Source', account_info, account_info[0], file_path, share_name,
+                         dst_file_path, share_name)
+        self.storage_cmd('storage file show --share-name {} --path {}', account_info, share_name, dst_file_path) \
+            .assert_with_checks(JMESPathCheck('fileMode', '0664'),
+                                JMESPathCheck('owner', '3'),
+                                JMESPathCheck('group', '4'))
+        dst_file2_path = dir_name + '/' + 'dst_file2.txt'
+        self.storage_cmd('storage file copy start --source-account-name {} --source-path {} --source-share {} '
+                         '--destination-path {} --destination-share {} --owner-copy-mode Override '
+                         '--file-mode-copy-mode Override --file-mode {} --owner {} --group {}',
+                         account_info, account_info[0], file_path, share_name, dst_file2_path, share_name,
+                         'rw-rw-rw-', '4', '5')
+        self.storage_cmd('storage file show --share-name {} --path {}', account_info, share_name, dst_file2_path) \
+            .assert_with_checks(JMESPathCheck('fileMode', '0666'),
+                                JMESPathCheck('owner', '4'),
+                                JMESPathCheck('group', '5'))
+
+        # hard link
+        link_path = dir_name + '/' + 'linked_file.txt'
+        self.storage_cmd('storage file hard-link create --share-name {} --path {} --target {}', account_info,
+                         share_name, link_path, file_path).\
+            assert_with_checks(JMESPathCheck('mode', '0664'),
+                               JMESPathCheck('owner', '3'),
+                               JMESPathCheck('group', '4'))
