@@ -35,7 +35,7 @@ def transform_vm(vm):
 
 
 def transform_vm_create_output(result):
-    from msrestazure.tools import parse_resource_id
+    from azure.mgmt.core.tools import parse_resource_id
     from collections import OrderedDict
     try:
         resource_group = getattr(result, 'resource_group', None) or parse_resource_id(result.id)['resource_group']
@@ -91,7 +91,7 @@ def transform_sku_for_table_output(skus):
                     reason += ', type: ' + x['type']
                 if x['restrictionInfo']['locations']:
                     reason += ', locations: ' + ','.join(x['restrictionInfo']['locations'])
-                if x['restrictionInfo']['zones']:
+                if x['restrictionInfo'].get('zones', None):
                     reason += ', zones: ' + ','.join(x['restrictionInfo']['zones'])
                 reasons.append(reason)
             order_dict['restrictions'] = str(reasons) if len(reasons) > 1 else reasons[0]
@@ -107,9 +107,14 @@ transform_extension_show_table_output = '{Name:name, ProvisioningState:provision
                                         'Version:typeHandlerVersion, AutoUpgradeMinorVersion:autoUpgradeMinorVersion}'
 
 
+transform_disk_create_table_output = '{Name:name, ResourceGroup:resourceGroup, Location:location, Zones: ' \
+                                     '(!zones && \' \') || join(` `, zones), Sku:sku.name, OsType:osType, ' \
+                                     'SizeGb:diskSizeGb, ProvisioningState:provisioningState}'
+
+
 transform_disk_show_table_output = '{Name:name, ResourceGroup:resourceGroup, Location:location, Zones: ' \
                                    '(!zones && \' \') || join(` `, zones), Sku:sku.name, OsType:osType, ' \
-                                   'SizeGb:diskSizeGb, ProvisioningState:provisioningState}'
+                                   'SizeGb:diskSizeGB, ProvisioningState:provisioningState}'
 
 
 def get_vmss_table_output_transformer(loader, for_list=True):
@@ -120,6 +125,16 @@ def get_vmss_table_output_transformer(loader, for_list=True):
     return transform if not for_list else '[].' + transform
 
 
+transform_vmss_list_with_zones_table_output = '[].{Name:name, ResourceGroup:resourceGroup, Location:location, ' \
+                                              'Zones: (!zones && \' \') || join(\' \', zones), ' \
+                                              'Capacity:sku.capacity, Overprovision:overprovision, ' \
+                                              'UpgradePolicy:upgradePolicy.mode}'
+
+transform_vmss_list_without_zones_table_output = '[].{Name:name, ResourceGroup:resourceGroup, Location:location, ' \
+                                                 'Capacity:sku.capacity, Overprovision:overprovision, ' \
+                                                 'UpgradePolicy:upgradePolicy.mode}'
+
+
 def transform_vm_encryption_show_table_output(result):
     from collections import OrderedDict
     if result.get("status", []):
@@ -134,14 +149,10 @@ def transform_log_analytics_query_output(result):
     tables_output = []
 
     def _transform_query_output(table):
-        columns = table.columns
         name = table.name
         rows = table.rows
-
-        column_names = []
+        column_names = table.columns
         table_output = []
-        for column in columns:
-            column_names.append(column.name)
         for row in rows:
             item = OrderedDict()
             item['TableName'] = name
